from __future__ import annotations


from pydantic.v1 import Field
from pydantic2_schemaorg.ItemAvailability import ItemAvailability


class Reserved(ItemAvailability):
    """Indicates that the item is reserved and therefore not available.

    See: https://schema.org/Reserved
    Model depth: 5
    """

    type_: str = Field(default="Reserved", alias="@type", const=True)



from __future__ import annotations


from pydantic.v1 import Field
from pydantic2_schemaorg.EventStatusType import EventStatusType


class EventMovedOnline(EventStatusType):
    """Indicates that the event was changed to allow online participation. See [[eventAttendanceMode]] for specifics
     of whether it is now fully or partially online.

    See: https://schema.org/EventMovedOnline
    Model depth: 6
    """

    type_: str = Field(default="EventMovedOnline", alias="@type", const=True)



from __future__ import annotations


from pydantic.v1 import Field
from pydantic2_schemaorg.Periodical import Periodical


class ComicSeries(Periodical):
    """A sequential publication of comic stories under a unifying title, for example \"The Amazing Spider-Man\"
     or \"Groo the Wanderer\".

    See: https://schema.org/ComicSeries
    Model depth: 5
    """

    type_: str = Field(default="ComicSeries", alias="@type", const=True)



from __future__ import annotations


from pydantic.v1 import Field
from pydantic2_schemaorg.DigitalPlatformEnumeration import DigitalPlatformEnumeration


class MobileWebPlatform(DigitalPlatformEnumeration):
    """Represents the broad notion of 'mobile' browsers as a Web Platform.

    See: https://schema.org/MobileWebPlatform
    Model depth: 5
    """

    type_: str = Field(default="MobileWebPlatform", alias="@type", const=True)



from __future__ import annotations


from pydantic.v1 import Field
from pydantic2_schemaorg.Permit import Permit


class GovernmentPermit(Permit):
    """A permit issued by a government agency.

    See: https://schema.org/GovernmentPermit
    Model depth: 4
    """

    type_: str = Field(default="GovernmentPermit", alias="@type", const=True)



from __future__ import annotations


from pydantic.v1 import Field
from pydantic2_schemaorg.Number import Number


class Integer(Number):
    """Data type: Integer.

    See: https://schema.org/Integer
    Model depth: 6
    """

    type_: str = Field(default="Integer", alias="@type", const=True)



from __future__ import annotations


from pydantic.v1 import Field
from pydantic2_schemaorg.HomeAndConstructionBusiness import HomeAndConstructionBusiness


class HousePainter(HomeAndConstructionBusiness):
    """A house painting service.

    See: https://schema.org/HousePainter
    Model depth: 5
    """

    type_: str = Field(default="HousePainter", alias="@type", const=True)



from __future__ import annotations


from pydantic.v1 import Field
from pydantic2_schemaorg.EducationalOrganization import EducationalOrganization


class MiddleSchool(EducationalOrganization):
    """A middle school (typically for children aged around 11-14, although this varies somewhat).

    See: https://schema.org/MiddleSchool
    Model depth: 4
    """

    type_: str = Field(default="MiddleSchool", alias="@type", const=True)



from __future__ import annotations


from pydantic.v1 import Field
from pydantic2_schemaorg.PhysicalActivityCategory import PhysicalActivityCategory


class AerobicActivity(PhysicalActivityCategory):
    """Physical activity of relatively low intensity that depends primarily on the aerobic energy-generating
     process; during activity, the aerobic metabolism uses oxygen to adequately meet energy demands during exercise.

    See: https://schema.org/AerobicActivity
    Model depth: 5
    """

    type_: str = Field(default="AerobicActivity", alias="@type", const=True)



from __future__ import annotations
from typing import TYPE_CHECKING

from typing import List, Optional, Union


from pydantic.v1 import Field
from pydantic2_schemaorg.Organization import Organization


class Corporation(Organization):
    """Organization: A business corporation.

    See: https://schema.org/Corporation
    Model depth: 3
    """

    type_: str = Field(default="Corporation", alias="@type", const=True)
    tickerSymbol: Optional[Union[List[Union[str, "Text"]], str, "Text"]] = Field(
        default=None,
        description="The exchange traded instrument associated with a Corporation object. The tickerSymbol is expressed as an exchange and an instrument name separated by a space character. For the exchange component of the tickerSymbol attribute, we recommend using the controlled vocabulary of Market Identifier Codes (MIC) specified in ISO 15022.",
    )


if TYPE_CHECKING:
    from pydantic2_schemaorg.Text import Text



from __future__ import annotations


from pydantic.v1 import Field
from pydantic2_schemaorg.TierBenefitEnumeration import TierBenefitEnumeration


class TierBenefitLoyaltyPoints(TierBenefitEnumeration):
    """Benefit of the tier is earning of loyalty points.

    See: https://schema.org/TierBenefitLoyaltyPoints
    Model depth: 5
    """

    type_: str = Field(default="TierBenefitLoyaltyPoints", alias="@type", const=True)



from __future__ import annotations


from pydantic.v1 import Field
from pydantic2_schemaorg.LodgingBusiness import LodgingBusiness


class Hostel(LodgingBusiness):
    """A hostel - cheap accommodation, often in shared dormitories. <br /><br /> See also the <a href=\"/docs/hotels.html\">dedicated
     document on the use of schema.org for marking up hotels and other forms of accommodations</a>.

    See: https://schema.org/Hostel
    Model depth: 5
    """

    type_: str = Field(default="Hostel", alias="@type", const=True)



from __future__ import annotations


from pydantic.v1 import Field
from pydantic2_schemaorg.Organization import Organization


class FundingScheme(Organization):
    """A FundingScheme combines organizational, project and policy aspects of grant-based funding that sets guidelines,
     principles and mechanisms to support other kinds of projects and activities. Funding is typically organized
     via [[Grant]] funding. Examples of funding schemes: Swiss Priority Programmes (SPPs); EU Framework 7 (FP7);
     Horizon 2020; the NIH-R01 Grant Program; Wellcome institutional strategic support fund. For large scale
     public sector funding, the management and administration of grant awards is often handled by other, dedicated,
     organizations - [[FundingAgency]]s such as ERC, REA, ...

    See: https://schema.org/FundingScheme
    Model depth: 3
    """

    type_: str = Field(default="FundingScheme", alias="@type", const=True)



from __future__ import annotations
from typing import TYPE_CHECKING

from typing import List, Optional, Union
from pydantic.v1 import AnyUrl, StrictBool, StrictInt, StrictFloat


from pydantic.v1 import Field
from pydantic2_schemaorg.Thing import Thing


class Place(Thing):
    """Entities that have a somewhat fixed, physical extension.

    See: https://schema.org/Place
    Model depth: 2
    """

    type_: str = Field(default="Place", alias="@type", const=True)
    containedIn: Optional[Union[List[Union["Place", str]], "Place", str]] = Field(
        default=None,
        description="The basic containment relation between a place and one that contains it.",
    )
    maximumAttendeeCapacity: Optional[
        Union[List[Union[int, "Integer", str]], int, "Integer", str]
    ] = Field(
        default=None,
        description="The total number of individuals that may attend an event or venue.",
    )
    maps: Optional[Union[List[Union[AnyUrl, "URL", str]], AnyUrl, "URL", str]] = Field(
        default=None,
        description="A URL to a map of the place.",
    )
    geoWithin: Optional[
        Union[
            List[Union["GeospatialGeometry", "Place", str]],
            "GeospatialGeometry",
            "Place",
            str,
        ]
    ] = Field(
        default=None,
        description="Represents a relationship between two geometries (or the places they represent), relating a geometry to one that contains it, i.e. it is inside (i.e. within) its interior. As defined in [DE-9IM](https://en.wikipedia.org/wiki/DE-9IM).",
    )
    faxNumber: Optional[Union[List[Union[str, "Text"]], str, "Text"]] = Field(
        default=None,
        description="The fax number.",
    )
    geoCovers: Optional[
        Union[
            List[Union["GeospatialGeometry", "Place", str]],
            "GeospatialGeometry",
            "Place",
            str,
        ]
    ] = Field(
        default=None,
        description='Represents a relationship between two geometries (or the places they represent), relating a covering geometry to a covered geometry. "Every point of b is a point of (the interior or boundary of) a". As defined in [DE-9IM](https://en.wikipedia.org/wiki/DE-9IM).',
    )
    branchCode: Optional[Union[List[Union[str, "Text"]], str, "Text"]] = Field(
        default=None,
        description='A short textual code (also called "store code") that uniquely identifies a place of business. The code is typically assigned by the parentOrganization and used in structured URLs. For example, in the URL http://www.starbucks.co.uk/store-locator/etc/detail/3047 the code "3047" is a branchCode for a particular branch.',
    )
    logo: Optional[
        Union[
            List[Union[AnyUrl, "URL", "ImageObject", str]],
            AnyUrl,
            "URL",
            "ImageObject",
            str,
        ]
    ] = Field(
        default=None,
        description="An associated logo.",
    )
    containsPlace: Optional[Union[List[Union["Place", str]], "Place", str]] = Field(
        default=None,
        description="The basic containment relation between a place and another that it contains.",
    )
    geoOverlaps: Optional[
        Union[
            List[Union["GeospatialGeometry", "Place", str]],
            "GeospatialGeometry",
            "Place",
            str,
        ]
    ] = Field(
        default=None,
        description="Represents a relationship between two geometries (or the places they represent), relating a geometry to another that geospatially overlaps it, i.e. they have some but not all points in common. As defined in [DE-9IM](https://en.wikipedia.org/wiki/DE-9IM).",
    )
    hasGS1DigitalLink: Optional[
        Union[List[Union[AnyUrl, "URL", str]], AnyUrl, "URL", str]
    ] = Field(
        default=None,
        description='The <a href="https://www.gs1.org/standards/gs1-digital-link">GS1 digital link</a> associated with the object. This URL should conform to the particular requirements of digital links. The link should only contain the Application Identifiers (AIs) that are relevant for the entity being annotated, for instance a [[Product]] or an [[Organization]], and for the correct granularity. In particular, for products:<ul><li>A Digital Link that contains a serial number (AI <code>21</code>) should only be present on instances of [[IndividualProduct]]</li><li>A Digital Link that contains a lot number (AI <code>10</code>) should be annotated as [[SomeProduct]] if only products from that lot are sold, or [[IndividualProduct]] if there is only a specific product.</li><li>A Digital Link that contains a global model number (AI <code>8013</code>) should be attached to a [[Product]] or a [[ProductModel]].</li></ul> Other item types should be adapted similarly.',
    )
    hasCertification: Optional[
        Union[List[Union["Certification", str]], "Certification", str]
    ] = Field(
        default=None,
        description="Certification information about a product, organization, service, place, or person.",
    )
    longitude: Optional[
        Union[
            List[Union[StrictInt, StrictFloat, "Number", str, "Text"]],
            StrictInt,
            StrictFloat,
            "Number",
            str,
            "Text",
        ]
    ] = Field(
        default=None,
        description="The longitude of a location. For example ```-122.08585``` ([WGS 84](https://en.wikipedia.org/wiki/World_Geodetic_System)).",
    )
    photo: Optional[
        Union[
            List[Union["Photograph", "ImageObject", str]],
            "Photograph",
            "ImageObject",
            str,
        ]
    ] = Field(
        default=None,
        description="A photograph of this place.",
    )
    aggregateRating: Optional[
        Union[List[Union["AggregateRating", str]], "AggregateRating", str]
    ] = Field(
        default=None,
        description="The overall rating, based on a collection of reviews or ratings, of the item.",
    )
    map: Optional[Union[List[Union[AnyUrl, "URL", str]], AnyUrl, "URL", str]] = Field(
        default=None,
        description="A URL to a map of the place.",
    )
    keywords: Optional[
        Union[
            List[Union[AnyUrl, "URL", str, "Text", "DefinedTerm"]],
            AnyUrl,
            "URL",
            str,
            "Text",
            "DefinedTerm",
        ]
    ] = Field(
        default=None,
        description="Keywords or tags used to describe some item. Multiple textual entries in a keywords list are typically delimited by commas, or by repeating the property.",
    )
    geoDisjoint: Optional[
        Union[
            List[Union["GeospatialGeometry", "Place", str]],
            "GeospatialGeometry",
            "Place",
            str,
        ]
    ] = Field(
        default=None,
        description='Represents spatial relations in which two geometries (or the places they represent) are topologically disjoint: "they have no point in common. They form a set of disconnected geometries." (A symmetric relationship, as defined in [DE-9IM](https://en.wikipedia.org/wiki/DE-9IM).)',
    )
    isAccessibleForFree: Optional[
        Union[List[Union[StrictBool, "Boolean", str]], StrictBool, "Boolean", str]
    ] = Field(
        default=None,
        description="A flag to signal that the item, event, or place is accessible for free.",
    )
    geoCrosses: Optional[
        Union[
            List[Union["GeospatialGeometry", "Place", str]],
            "GeospatialGeometry",
            "Place",
            str,
        ]
    ] = Field(
        default=None,
        description='Represents a relationship between two geometries (or the places they represent), relating a geometry to another that crosses it: "a crosses b: they have some but not all interior points in common, and the dimension of the intersection is less than that of at least one of them". As defined in [DE-9IM](https://en.wikipedia.org/wiki/DE-9IM).',
    )
    latitude: Optional[
        Union[
            List[Union[StrictInt, StrictFloat, "Number", str, "Text"]],
            StrictInt,
            StrictFloat,
            "Number",
            str,
            "Text",
        ]
    ] = Field(
        default=None,
        description="The latitude of a location. For example ```37.42242``` ([WGS 84](https://en.wikipedia.org/wiki/World_Geodetic_System)).",
    )
    isicV4: Optional[Union[List[Union[str, "Text"]], str, "Text"]] = Field(
        default=None,
        description="The International Standard of Industrial Classification of All Economic Activities (ISIC), Revision 4 code for a particular organization, business person, or place.",
    )
    geoTouches: Optional[
        Union[
            List[Union["GeospatialGeometry", "Place", str]],
            "GeospatialGeometry",
            "Place",
            str,
        ]
    ] = Field(
        default=None,
        description='Represents spatial relations in which two geometries (or the places they represent) touch: "they have at least one boundary point in common, but no interior points." (A symmetric relationship, as defined in [DE-9IM](https://en.wikipedia.org/wiki/DE-9IM).)',
    )
    containedInPlace: Optional[Union[List[Union["Place", str]], "Place", str]] = Field(
        default=None,
        description="The basic containment relation between a place and one that contains it.",
    )
    publicAccess: Optional[
        Union[List[Union[StrictBool, "Boolean", str]], StrictBool, "Boolean", str]
    ] = Field(
        default=None,
        description="A flag to signal that the [[Place]] is open to public visitors. If this property is omitted there is no assumed default boolean value.",
    )
    openingHoursSpecification: Optional[
        Union[
            List[Union["OpeningHoursSpecification", str]],
            "OpeningHoursSpecification",
            str,
        ]
    ] = Field(
        default=None,
        description="The opening hours of a certain place.",
    )
    globalLocationNumber: Optional[Union[List[Union[str, "Text"]], str, "Text"]] = (
        Field(
            default=None,
            description="The [Global Location Number](http://www.gs1.org/gln) (GLN, sometimes also referred to as International Location Number or ILN) of the respective organization, person, or place. The GLN is a 13-digit number used to identify parties and physical locations.",
        )
    )
    slogan: Optional[Union[List[Union[str, "Text"]], str, "Text"]] = Field(
        default=None,
        description="A slogan or motto associated with the item.",
    )
    event: Optional[Union[List[Union["Event", str]], "Event", str]] = Field(
        default=None,
        description="Upcoming or past event associated with this place, organization, or action.",
    )
    hasDriveThroughService: Optional[
        Union[List[Union[StrictBool, "Boolean", str]], StrictBool, "Boolean", str]
    ] = Field(
        default=None,
        description="Indicates whether some facility (e.g. [[FoodEstablishment]], [[CovidTestingFacility]]) offers a service that can be used by driving through in a car. In the case of [[CovidTestingFacility]] such facilities could potentially help with social distancing from other potentially-infected users.",
    )
    geoContains: Optional[
        Union[
            List[Union["GeospatialGeometry", "Place", str]],
            "GeospatialGeometry",
            "Place",
            str,
        ]
    ] = Field(
        default=None,
        description='Represents a relationship between two geometries (or the places they represent), relating a containing geometry to a contained geometry. "a contains b iff no points of b lie in the exterior of a, and at least one point of the interior of b lies in the interior of a". As defined in [DE-9IM](https://en.wikipedia.org/wiki/DE-9IM).',
    )
    geoCoveredBy: Optional[
        Union[
            List[Union["GeospatialGeometry", "Place", str]],
            "GeospatialGeometry",
            "Place",
            str,
        ]
    ] = Field(
        default=None,
        description="Represents a relationship between two geometries (or the places they represent), relating a geometry to another that covers it. As defined in [DE-9IM](https://en.wikipedia.org/wiki/DE-9IM).",
    )
    review: Optional[Union[List[Union["Review", str]], "Review", str]] = Field(
        default=None,
        description="A review of the item.",
    )
    amenityFeature: Optional[
        Union[
            List[Union["LocationFeatureSpecification", str]],
            "LocationFeatureSpecification",
            str,
        ]
    ] = Field(
        default=None,
        description="An amenity feature (e.g. a characteristic or service) of the Accommodation. This generic property does not make a statement about whether the feature is included in an offer for the main accommodation or available at extra costs.",
    )
    geo: Optional[
        Union[
            List[Union["GeoCoordinates", "GeoShape", str]],
            "GeoCoordinates",
            "GeoShape",
            str,
        ]
    ] = Field(
        default=None,
        description="The geo coordinates of the place.",
    )
    additionalProperty: Optional[
        Union[List[Union["PropertyValue", str]], "PropertyValue", str]
    ] = Field(
        default=None,
        description="A property-value pair representing an additional characteristic of the entity, e.g. a product feature or another characteristic for which there is no matching property in schema.org. Note: Publishers should be aware that applications designed to use specific schema.org properties (e.g. https://schema.org/width, https://schema.org/color, https://schema.org/gtin13, ...) will typically expect such data to be provided using those properties, rather than using the generic property/value mechanism.",
    )
    geoIntersects: Optional[
        Union[
            List[Union["GeospatialGeometry", "Place", str]],
            "GeospatialGeometry",
            "Place",
            str,
        ]
    ] = Field(
        default=None,
        description="Represents spatial relations in which two geometries (or the places they represent) have at least one point in common. As defined in [DE-9IM](https://en.wikipedia.org/wiki/DE-9IM).",
    )
    geoEquals: Optional[
        Union[
            List[Union["GeospatialGeometry", "Place", str]],
            "GeospatialGeometry",
            "Place",
            str,
        ]
    ] = Field(
        default=None,
        description='Represents spatial relations in which two geometries (or the places they represent) are topologically equal, as defined in [DE-9IM](https://en.wikipedia.org/wiki/DE-9IM). "Two geometries are topologically equal if their interiors intersect and no part of the interior or boundary of one geometry intersects the exterior of the other" (a symmetric relationship).',
    )
    tourBookingPage: Optional[
        Union[List[Union[AnyUrl, "URL", str]], AnyUrl, "URL", str]
    ] = Field(
        default=None,
        description="A page providing information on how to book a tour of some [[Place]], such as an [[Accommodation]] or [[ApartmentComplex]] in a real estate setting, as well as other kinds of tours as appropriate.",
    )
    photos: Optional[
        Union[
            List[Union["Photograph", "ImageObject", str]],
            "Photograph",
            "ImageObject",
            str,
        ]
    ] = Field(
        default=None,
        description="Photographs of this place.",
    )
    hasMap: Optional[
        Union[List[Union[AnyUrl, "URL", "Map", str]], AnyUrl, "URL", "Map", str]
    ] = Field(
        default=None,
        description="A URL to a map of the place.",
    )
    specialOpeningHoursSpecification: Optional[
        Union[
            List[Union["OpeningHoursSpecification", str]],
            "OpeningHoursSpecification",
            str,
        ]
    ] = Field(
        default=None,
        description="The special opening hours of a certain place. Use this to explicitly override general opening hours brought in scope by [[openingHoursSpecification]] or [[openingHours]].",
    )
    smokingAllowed: Optional[
        Union[List[Union[StrictBool, "Boolean", str]], StrictBool, "Boolean", str]
    ] = Field(
        default=None,
        description="Indicates whether it is allowed to smoke in the place, e.g. in the restaurant, hotel or hotel room.",
    )
    telephone: Optional[Union[List[Union[str, "Text"]], str, "Text"]] = Field(
        default=None,
        description="The telephone number.",
    )
    address: Optional[
        Union[List[Union[str, "Text", "PostalAddress"]], str, "Text", "PostalAddress"]
    ] = Field(
        default=None,
        description="Physical address of the item.",
    )
    reviews: Optional[Union[List[Union["Review", str]], "Review", str]] = Field(
        default=None,
        description="Review of the item.",
    )
    events: Optional[Union[List[Union["Event", str]], "Event", str]] = Field(
        default=None,
        description="Upcoming or past events associated with this place or organization.",
    )


if TYPE_CHECKING:
    from pydantic2_schemaorg.Integer import Integer
    from pydantic2_schemaorg.URL import URL
    from pydantic2_schemaorg.GeospatialGeometry import GeospatialGeometry
    from pydantic2_schemaorg.Text import Text
    from pydantic2_schemaorg.ImageObject import ImageObject
    from pydantic2_schemaorg.Certification import Certification
    from pydantic2_schemaorg.Number import Number
    from pydantic2_schemaorg.Photograph import Photograph
    from pydantic2_schemaorg.AggregateRating import AggregateRating
    from pydantic2_schemaorg.DefinedTerm import DefinedTerm
    from pydantic2_schemaorg.Boolean import Boolean
    from pydantic2_schemaorg.OpeningHoursSpecification import OpeningHoursSpecification
    from pydantic2_schemaorg.Event import Event
    from pydantic2_schemaorg.Review import Review
    from pydantic2_schemaorg.LocationFeatureSpecification import (
        LocationFeatureSpecification,
    )
    from pydantic2_schemaorg.GeoCoordinates import GeoCoordinates
    from pydantic2_schemaorg.GeoShape import GeoShape
    from pydantic2_schemaorg.PropertyValue import PropertyValue
    from pydantic2_schemaorg.Map import Map
    from pydantic2_schemaorg.PostalAddress import PostalAddress



from __future__ import annotations
from typing import TYPE_CHECKING

from typing import List, Optional, Union


from pydantic.v1 import Field
from pydantic2_schemaorg.Place import Place


class Residence(Place):
    """The place where a person lives.

    See: https://schema.org/Residence
    Model depth: 3
    """

    type_: str = Field(default="Residence", alias="@type", const=True)
    accommodationFloorPlan: Optional[
        Union[List[Union["FloorPlan", str]], "FloorPlan", str]
    ] = Field(
        default=None,
        description="A floorplan of some [[Accommodation]].",
    )


if TYPE_CHECKING:
    from pydantic2_schemaorg.FloorPlan import FloorPlan



from __future__ import annotations


from pydantic.v1 import Field
from pydantic2_schemaorg.MapCategoryType import MapCategoryType


class TransitMap(MapCategoryType):
    """A transit map.

    See: https://schema.org/TransitMap
    Model depth: 5
    """

    type_: str = Field(default="TransitMap", alias="@type", const=True)



from __future__ import annotations


from pydantic.v1 import Field
from pydantic2_schemaorg.MerchantReturnEnumeration import MerchantReturnEnumeration


class MerchantReturnUnlimitedWindow(MerchantReturnEnumeration):
    """Specifies that there is an unlimited window for product returns.

    See: https://schema.org/MerchantReturnUnlimitedWindow
    Model depth: 5
    """

    type_: str = Field(
        default="MerchantReturnUnlimitedWindow", alias="@type", const=True
    )



from __future__ import annotations
from typing import TYPE_CHECKING

from typing import List, Optional, Union
from pydantic.v1 import StrictInt, StrictFloat


from pydantic.v1 import Field
from pydantic2_schemaorg.Grant import Grant


class MonetaryGrant(Grant):
    """A monetary grant.

    See: https://schema.org/MonetaryGrant
    Model depth: 4
    """

    type_: str = Field(default="MonetaryGrant", alias="@type", const=True)
    funder: Optional[
        Union[List[Union["Person", "Organization", str]], "Person", "Organization", str]
    ] = Field(
        default=None,
        description="A person or organization that supports (sponsors) something through some kind of financial contribution.",
    )
    amount: Optional[
        Union[
            List[Union[StrictInt, StrictFloat, "Number", "MonetaryAmount", str]],
            StrictInt,
            StrictFloat,
            "Number",
            "MonetaryAmount",
            str,
        ]
    ] = Field(
        default=None,
        description="The amount of money.",
    )


if TYPE_CHECKING:
    from pydantic2_schemaorg.Person import Person
    from pydantic2_schemaorg.Organization import Organization
    from pydantic2_schemaorg.Number import Number
    from pydantic2_schemaorg.MonetaryAmount import MonetaryAmount



from __future__ import annotations
from typing import TYPE_CHECKING

from typing import List, Optional, Union


from pydantic.v1 import Field
from pydantic2_schemaorg.Comment import Comment


class Answer(Comment):
    """An answer offered to a question; perhaps correct, perhaps opinionated or wrong.

    See: https://schema.org/Answer
    Model depth: 4
    """

    type_: str = Field(default="Answer", alias="@type", const=True)
    parentItem: Optional[
        Union[
            List[Union["Comment", "CreativeWork", str]], "Comment", "CreativeWork", str
        ]
    ] = Field(
        default=None,
        description="The parent of a question, answer or item in general. Typically used for Q/A discussion threads e.g. a chain of comments with the first comment being an [[Article]] or other [[CreativeWork]]. See also [[comment]] which points from something to a comment about it.",
    )
    answerExplanation: Optional[
        Union[List[Union["Comment", "WebContent", str]], "Comment", "WebContent", str]
    ] = Field(
        default=None,
        description="A step-by-step or full explanation about Answer. Can outline how this Answer was achieved or contain more broad clarification or statement about it.",
    )


if TYPE_CHECKING:
    from pydantic2_schemaorg.Comment import Comment
    from pydantic2_schemaorg.CreativeWork import CreativeWork
    from pydantic2_schemaorg.WebContent import WebContent



from __future__ import annotations


from pydantic.v1 import Field
from pydantic2_schemaorg.GovernmentBenefitsType import GovernmentBenefitsType


class BasicIncome(GovernmentBenefitsType):
    """BasicIncome: this is a benefit for basic income.

    See: https://schema.org/BasicIncome
    Model depth: 5
    """

    type_: str = Field(default="BasicIncome", alias="@type", const=True)



from __future__ import annotations


from pydantic.v1 import Field
from pydantic2_schemaorg.CivicStructure import CivicStructure


class Museum(CivicStructure):
    """A museum.

    See: https://schema.org/Museum
    Model depth: 4
    """

    type_: str = Field(default="Museum", alias="@type", const=True)



from __future__ import annotations
from typing import TYPE_CHECKING

from typing import List, Optional, Union


from pydantic.v1 import Field
from pydantic2_schemaorg.Service import Service


class GovernmentService(Service):
    """A service provided by a government organization, e.g. food stamps, veterans benefits, etc.

    See: https://schema.org/GovernmentService
    Model depth: 4
    """

    type_: str = Field(default="GovernmentService", alias="@type", const=True)
    jurisdiction: Optional[
        Union[
            List[Union[str, "Text", "AdministrativeArea"]],
            str,
            "Text",
            "AdministrativeArea",
        ]
    ] = Field(
        default=None,
        description="Indicates a legal jurisdiction, e.g. of some legislation, or where some government service is based.",
    )
    serviceOperator: Optional[
        Union[List[Union["Organization", str]], "Organization", str]
    ] = Field(
        default=None,
        description="The operating organization, if different from the provider. This enables the representation of services that are provided by an organization, but operated by another organization like a subcontractor.",
    )


if TYPE_CHECKING:
    from pydantic2_schemaorg.Text import Text
    from pydantic2_schemaorg.AdministrativeArea import AdministrativeArea
    from pydantic2_schemaorg.Organization import Organization



from __future__ import annotations
from typing import TYPE_CHECKING

from typing import List, Optional, Union
from pydantic.v1 import AnyUrl
from datetime import date, datetime


from pydantic.v1 import Field
from pydantic2_schemaorg.Intangible import Intangible


class ParcelDelivery(Intangible):
    """The delivery of a parcel either via the postal service or a commercial service.

    See: https://schema.org/ParcelDelivery
    Model depth: 3
    """

    type_: str = Field(default="ParcelDelivery", alias="@type", const=True)
    originAddress: Optional[
        Union[List[Union["PostalAddress", str]], "PostalAddress", str]
    ] = Field(
        default=None,
        description="Shipper's address.",
    )
    partOfOrder: Optional[Union[List[Union["Order", str]], "Order", str]] = Field(
        default=None,
        description="The overall order the items in this delivery were included in.",
    )
    deliveryStatus: Optional[
        Union[List[Union["DeliveryEvent", str]], "DeliveryEvent", str]
    ] = Field(
        default=None,
        description="New entry added as the package passes through each leg of its journey (from shipment to final delivery).",
    )
    deliveryAddress: Optional[
        Union[List[Union["PostalAddress", str]], "PostalAddress", str]
    ] = Field(
        default=None,
        description="Destination address.",
    )
    hasDeliveryMethod: Optional[
        Union[List[Union["DeliveryMethod", str]], "DeliveryMethod", str]
    ] = Field(
        default=None,
        description="Method used for delivery or shipping.",
    )
    trackingUrl: Optional[
        Union[List[Union[AnyUrl, "URL", str]], AnyUrl, "URL", str]
    ] = Field(
        default=None,
        description="Tracking url for the parcel delivery.",
    )
    itemShipped: Optional[Union[List[Union["Product", str]], "Product", str]] = Field(
        default=None,
        description="Item(s) being shipped.",
    )
    expectedArrivalFrom: Optional[
        Union[
            List[Union[datetime, "DateTime", date, "Date", str]],
            datetime,
            "DateTime",
            date,
            "Date",
            str,
        ]
    ] = Field(
        default=None,
        description="The earliest date the package may arrive.",
    )
    provider: Optional[
        Union[List[Union["Person", "Organization", str]], "Person", "Organization", str]
    ] = Field(
        default=None,
        description="The service provider, service operator, or service performer; the goods producer. Another party (a seller) may offer those services or goods on behalf of the provider. A provider may also serve as the seller.",
    )
    trackingNumber: Optional[Union[List[Union[str, "Text"]], str, "Text"]] = Field(
        default=None,
        description="Shipper tracking number.",
    )
    expectedArrivalUntil: Optional[
        Union[
            List[Union[datetime, "DateTime", date, "Date", str]],
            datetime,
            "DateTime",
            date,
            "Date",
            str,
        ]
    ] = Field(
        default=None,
        description="The latest date the package may arrive.",
    )
    carrier: Optional[Union[List[Union["Organization", str]], "Organization", str]] = (
        Field(
            default=None,
            description="'carrier' is an out-dated term indicating the 'provider' for parcel delivery and flights.",
        )
    )


if TYPE_CHECKING:
    from pydantic2_schemaorg.PostalAddress import PostalAddress
    from pydantic2_schemaorg.Order import Order
    from pydantic2_schemaorg.DeliveryEvent import DeliveryEvent
    from pydantic2_schemaorg.DeliveryMethod import DeliveryMethod
    from pydantic2_schemaorg.URL import URL
    from pydantic2_schemaorg.Product import Product
    from pydantic2_schemaorg.DateTime import DateTime
    from pydantic2_schemaorg.Date import Date
    from pydantic2_schemaorg.Person import Person
    from pydantic2_schemaorg.Organization import Organization
    from pydantic2_schemaorg.Text import Text



from __future__ import annotations


from pydantic.v1 import Field
from pydantic2_schemaorg.InvestmentOrDeposit import InvestmentOrDeposit


class BrokerageAccount(InvestmentOrDeposit):
    """An account that allows an investor to deposit funds and place investment orders with a licensed broker or brokerage
     firm.

    See: https://schema.org/BrokerageAccount
    Model depth: 6
    """

    type_: str = Field(default="BrokerageAccount", alias="@type", const=True)



from __future__ import annotations


from pydantic.v1 import Field
from pydantic2_schemaorg.RestrictedDiet import RestrictedDiet


class KosherDiet(RestrictedDiet):
    """A diet conforming to Jewish dietary practices.

    See: https://schema.org/KosherDiet
    Model depth: 5
    """

    type_: str = Field(default="KosherDiet", alias="@type", const=True)



from __future__ import annotations


from pydantic.v1 import Field
from pydantic2_schemaorg.MedicalRiskEstimator import MedicalRiskEstimator


class MedicalRiskCalculator(MedicalRiskEstimator):
    """A complex mathematical calculation requiring an online calculator, used to assess prognosis. Note: use
     the url property of Thing to record any URLs for online calculators.

    See: https://schema.org/MedicalRiskCalculator
    Model depth: 4
    """

    type_: str = Field(default="MedicalRiskCalculator", alias="@type", const=True)



from __future__ import annotations


from pydantic.v1 import Field
from pydantic2_schemaorg.Enumeration import Enumeration


class PaymentMethodType(Enumeration):
    """The type of payment method, only for generic payment types, specific forms of payments, like card payment
     should be expressed using subclasses of PaymentMethod.

    See: https://schema.org/PaymentMethodType
    Model depth: 4
    """

    type_: str = Field(default="PaymentMethodType", alias="@type", const=True)



from __future__ import annotations


from pydantic.v1 import Field
from pydantic2_schemaorg.MedicalSpecialty import MedicalSpecialty
from pydantic2_schemaorg.MedicalBusiness import MedicalBusiness


class PrimaryCare(MedicalSpecialty, MedicalBusiness):
    """The medical care by a physician, or other health-care professional, who is the patient's first contact with
     the health-care system and who may recommend a specialist if necessary.

    See: https://schema.org/PrimaryCare
    Model depth: 5
    """

    type_: str = Field(default="PrimaryCare", alias="@type", const=True)



from __future__ import annotations


from pydantic.v1 import Field
from pydantic2_schemaorg.BodyMeasurementTypeEnumeration import (
    BodyMeasurementTypeEnumeration,
)


class BodyMeasurementHips(BodyMeasurementTypeEnumeration):
    """Girth of hips (measured around the buttocks). Used, for example, to fit skirts.

    See: https://schema.org/BodyMeasurementHips
    Model depth: 6
    """

    type_: str = Field(default="BodyMeasurementHips", alias="@type", const=True)



from __future__ import annotations


from pydantic.v1 import Field
from pydantic2_schemaorg.USNonprofitType import USNonprofitType


class Nonprofit501c24(USNonprofitType):
    """Nonprofit501c24: Non-profit type referring to Section 4049 ERISA Trusts.

    See: https://schema.org/Nonprofit501c24
    Model depth: 6
    """

    type_: str = Field(default="Nonprofit501c24", alias="@type", const=True)



from __future__ import annotations


from pydantic.v1 import Field
from pydantic2_schemaorg.USNonprofitType import USNonprofitType


class Nonprofit501c19(USNonprofitType):
    """Nonprofit501c19: Non-profit type referring to Post or Organization of Past or Present Members of the Armed
     Forces.

    See: https://schema.org/Nonprofit501c19
    Model depth: 6
    """

    type_: str = Field(default="Nonprofit501c19", alias="@type", const=True)



from __future__ import annotations
from typing import TYPE_CHECKING

from pydantic.v1 import AnyUrl
from typing import List, Optional, Union


from pydantic.v1 import Field
from pydantic2_schemaorg.CreativeWork import CreativeWork


class DataCatalog(CreativeWork):
    """A collection of datasets.

    See: https://schema.org/DataCatalog
    Model depth: 3
    """

    type_: str = Field(default="DataCatalog", alias="@type", const=True)
    measurementTechnique: Optional[
        Union[
            List[
                Union[
                    AnyUrl, "URL", str, "Text", "MeasurementMethodEnum", "DefinedTerm"
                ]
            ],
            AnyUrl,
            "URL",
            str,
            "Text",
            "MeasurementMethodEnum",
            "DefinedTerm",
        ]
    ] = Field(
        default=None,
        description='A technique, method or technology used in an [[Observation]], [[StatisticalVariable]] or [[Dataset]] (or [[DataDownload]], [[DataCatalog]]), corresponding to the method used for measuring the corresponding variable(s) (for datasets, described using [[variableMeasured]]; for [[Observation]], a [[StatisticalVariable]]). Often but not necessarily each [[variableMeasured]] will have an explicit representation as (or mapping to) an property such as those defined in Schema.org, or other RDF vocabularies and "knowledge graphs". In that case the subproperty of [[variableMeasured]] called [[measuredProperty]] is applicable. The [[measurementTechnique]] property helps when extra clarification is needed about how a [[measuredProperty]] was measured. This is oriented towards scientific and scholarly dataset publication but may have broader applicability; it is not intended as a full representation of measurement, but can often serve as a high level summary for dataset discovery. For example, if [[variableMeasured]] is: molecule concentration, [[measurementTechnique]] could be: "mass spectrometry" or "nmr spectroscopy" or "colorimetry" or "immunofluorescence". If the [[variableMeasured]] is "depression rating", the [[measurementTechnique]] could be "Zung Scale" or "HAM-D" or "Beck Depression Inventory". If there are several [[variableMeasured]] properties recorded for some given data object, use a [[PropertyValue]] for each [[variableMeasured]] and attach the corresponding [[measurementTechnique]]. The value can also be from an enumeration, organized as a [[MeasurementMetholdEnumeration]].',
    )
    dataset: Optional[Union[List[Union["Dataset", str]], "Dataset", str]] = Field(
        default=None,
        description="A dataset contained in this catalog.",
    )
    measurementMethod: Optional[
        Union[
            List[
                Union[
                    AnyUrl, "URL", str, "Text", "MeasurementMethodEnum", "DefinedTerm"
                ]
            ],
            AnyUrl,
            "URL",
            str,
            "Text",
            "MeasurementMethodEnum",
            "DefinedTerm",
        ]
    ] = Field(
        default=None,
        description="A subproperty of [[measurementTechnique]] that can be used for specifying specific methods, in particular via [[MeasurementMethodEnum]].",
    )


if TYPE_CHECKING:
    from pydantic2_schemaorg.URL import URL
    from pydantic2_schemaorg.Text import Text
    from pydantic2_schemaorg.MeasurementMethodEnum import MeasurementMethodEnum
    from pydantic2_schemaorg.DefinedTerm import DefinedTerm
    from pydantic2_schemaorg.Dataset import Dataset



from __future__ import annotations


from pydantic.v1 import Field
from pydantic2_schemaorg.InteractAction import InteractAction


class MarryAction(InteractAction):
    """The act of marrying a person.

    See: https://schema.org/MarryAction
    Model depth: 4
    """

    type_: str = Field(default="MarryAction", alias="@type", const=True)



from __future__ import annotations


from pydantic.v1 import Field
from pydantic2_schemaorg.HealthAspectEnumeration import HealthAspectEnumeration


class MayTreatHealthAspect(HealthAspectEnumeration):
    """Related topics may be treated by a Topic.

    See: https://schema.org/MayTreatHealthAspect
    Model depth: 5
    """

    type_: str = Field(default="MayTreatHealthAspect", alias="@type", const=True)



from __future__ import annotations
from typing import TYPE_CHECKING

from pydantic.v1 import AnyUrl
from typing import List, Optional, Union


from pydantic.v1 import Field
from pydantic2_schemaorg.Thing import Thing


class BioChemEntity(Thing):
    """Any biological, chemical, or biochemical thing. For example: a protein; a gene; a chemical; a synthetic chemical.

    See: https://schema.org/BioChemEntity
    Model depth: 2
    """

    type_: str = Field(default="BioChemEntity", alias="@type", const=True)
    taxonomicRange: Optional[
        Union[
            List[Union[AnyUrl, "URL", str, "Text", "Taxon", "DefinedTerm"]],
            AnyUrl,
            "URL",
            str,
            "Text",
            "Taxon",
            "DefinedTerm",
        ]
    ] = Field(
        default=None,
        description="The taxonomic grouping of the organism that expresses, encodes, or in some way related to the BioChemEntity.",
    )
    associatedDisease: Optional[
        Union[
            List[Union[AnyUrl, "URL", "MedicalCondition", "PropertyValue", str]],
            AnyUrl,
            "URL",
            "MedicalCondition",
            "PropertyValue",
            str,
        ]
    ] = Field(
        default=None,
        description="Disease associated to this BioChemEntity. Such disease can be a MedicalCondition or a URL. If you want to add an evidence supporting the association, please use PropertyValue.",
    )
    hasMolecularFunction: Optional[
        Union[
            List[Union[AnyUrl, "URL", "DefinedTerm", "PropertyValue", str]],
            AnyUrl,
            "URL",
            "DefinedTerm",
            "PropertyValue",
            str,
        ]
    ] = Field(
        default=None,
        description="Molecular function performed by this BioChemEntity; please use PropertyValue if you want to include any evidence.",
    )
    biologicalRole: Optional[
        Union[List[Union["DefinedTerm", str]], "DefinedTerm", str]
    ] = Field(
        default=None,
        description="A role played by the BioChemEntity within a biological context.",
    )
    isInvolvedInBiologicalProcess: Optional[
        Union[
            List[Union[AnyUrl, "URL", "DefinedTerm", "PropertyValue", str]],
            AnyUrl,
            "URL",
            "DefinedTerm",
            "PropertyValue",
            str,
        ]
    ] = Field(
        default=None,
        description="Biological process this BioChemEntity is involved in; please use PropertyValue if you want to include any evidence.",
    )
    bioChemInteraction: Optional[
        Union[List[Union["BioChemEntity", str]], "BioChemEntity", str]
    ] = Field(
        default=None,
        description="A BioChemEntity that is known to interact with this item.",
    )
    isLocatedInSubcellularLocation: Optional[
        Union[
            List[Union[AnyUrl, "URL", "DefinedTerm", "PropertyValue", str]],
            AnyUrl,
            "URL",
            "DefinedTerm",
            "PropertyValue",
            str,
        ]
    ] = Field(
        default=None,
        description="Subcellular location where this BioChemEntity is located; please use PropertyValue if you want to include any evidence.",
    )
    bioChemSimilarity: Optional[
        Union[List[Union["BioChemEntity", str]], "BioChemEntity", str]
    ] = Field(
        default=None,
        description="A similar BioChemEntity, e.g., obtained by fingerprint similarity algorithms.",
    )
    isEncodedByBioChemEntity: Optional[Union[List[Union["Gene", str]], "Gene", str]] = (
        Field(
            default=None,
            description="Another BioChemEntity encoding by this one.",
        )
    )
    hasBioChemEntityPart: Optional[
        Union[List[Union["BioChemEntity", str]], "BioChemEntity", str]
    ] = Field(
        default=None,
        description="Indicates a BioChemEntity that (in some sense) has this BioChemEntity as a part.",
    )
    isPartOfBioChemEntity: Optional[
        Union[List[Union["BioChemEntity", str]], "BioChemEntity", str]
    ] = Field(
        default=None,
        description="Indicates a BioChemEntity that is (in some sense) a part of this BioChemEntity.",
    )
    hasRepresentation: Optional[
        Union[
            List[Union[AnyUrl, "URL", str, "Text", "PropertyValue"]],
            AnyUrl,
            "URL",
            str,
            "Text",
            "PropertyValue",
        ]
    ] = Field(
        default=None,
        description="A common representation such as a protein sequence or chemical structure for this entity. For images use schema.org/image.",
    )
    funding: Optional[Union[List[Union["Grant", str]], "Grant", str]] = Field(
        default=None,
        description="A [[Grant]] that directly or indirectly provide funding or sponsorship for this item. See also [[ownershipFundingInfo]].",
    )


if TYPE_CHECKING:
    from pydantic2_schemaorg.URL import URL
    from pydantic2_schemaorg.Text import Text
    from pydantic2_schemaorg.Taxon import Taxon
    from pydantic2_schemaorg.DefinedTerm import DefinedTerm
    from pydantic2_schemaorg.MedicalCondition import MedicalCondition
    from pydantic2_schemaorg.PropertyValue import PropertyValue
    from pydantic2_schemaorg.Gene import Gene
    from pydantic2_schemaorg.Grant import Grant



from __future__ import annotations


from pydantic.v1 import Field
from pydantic2_schemaorg.MedicalProcedureType import MedicalProcedureType


class PercutaneousProcedure(MedicalProcedureType):
    """A type of medical procedure that involves percutaneous techniques, where access to organs or tissue is achieved
     via needle-puncture of the skin. For example, catheter-based procedures like stent delivery.

    See: https://schema.org/PercutaneousProcedure
    Model depth: 6
    """

    type_: str = Field(default="PercutaneousProcedure", alias="@type", const=True)



from __future__ import annotations
from typing import TYPE_CHECKING

from typing import List, Optional, Union


from pydantic.v1 import Field
from pydantic2_schemaorg.InteractAction import InteractAction


class LeaveAction(InteractAction):
    """An agent leaves an event / group with participants/friends at a location. Related actions: * [[JoinAction]]:
     The antonym of LeaveAction. * [[UnRegisterAction]]: Unlike UnRegisterAction, LeaveAction implies leaving
     a group/team of people rather than a service.

    See: https://schema.org/LeaveAction
    Model depth: 4
    """

    type_: str = Field(default="LeaveAction", alias="@type", const=True)
    event: Optional[Union[List[Union["Event", str]], "Event", str]] = Field(
        default=None,
        description="Upcoming or past event associated with this place, organization, or action.",
    )


if TYPE_CHECKING:
    from pydantic2_schemaorg.Event import Event



from __future__ import annotations
from typing import TYPE_CHECKING

from typing import List, Optional, Union


from pydantic.v1 import Field
from pydantic2_schemaorg.CreativeWork import CreativeWork


class PublicationVolume(CreativeWork):
    """A part of a successively published publication such as a periodical or multi-volume work, often numbered.
     It may represent a time span, such as a year. See also [blog post](http://blog.schema.org/2014/09/schemaorg-support-for-bibliographic_2.html).

    See: https://schema.org/PublicationVolume
    Model depth: 3
    """

    type_: str = Field(default="PublicationVolume", alias="@type", const=True)
    pageStart: Optional[
        Union[List[Union[int, "Integer", str, "Text"]], int, "Integer", str, "Text"]
    ] = Field(
        default=None,
        description='The page on which the work starts; for example "135" or "xiii".',
    )
    volumeNumber: Optional[
        Union[List[Union[int, "Integer", str, "Text"]], int, "Integer", str, "Text"]
    ] = Field(
        default=None,
        description='Identifies the volume of publication or multi-part work; for example, "iii" or "2".',
    )
    pagination: Optional[Union[List[Union[str, "Text"]], str, "Text"]] = Field(
        default=None,
        description='Any description of pages that is not separated into pageStart and pageEnd; for example, "1-6, 9, 55" or "10-12, 46-49".',
    )
    pageEnd: Optional[
        Union[List[Union[int, "Integer", str, "Text"]], int, "Integer", str, "Text"]
    ] = Field(
        default=None,
        description='The page on which the work ends; for example "138" or "xvi".',
    )


if TYPE_CHECKING:
    from pydantic2_schemaorg.Integer import Integer
    from pydantic2_schemaorg.Text import Text



from __future__ import annotations
from typing import TYPE_CHECKING

from typing import List, Optional, Union


from pydantic.v1 import Field
from pydantic2_schemaorg.CreativeWork import CreativeWork


class Map(CreativeWork):
    """A map.

    See: https://schema.org/Map
    Model depth: 3
    """

    type_: str = Field(default="Map", alias="@type", const=True)
    mapType: Optional[
        Union[List[Union["MapCategoryType", str]], "MapCategoryType", str]
    ] = Field(
        default=None,
        description="Indicates the kind of Map, from the MapCategoryType Enumeration.",
    )


if TYPE_CHECKING:
    from pydantic2_schemaorg.MapCategoryType import MapCategoryType



from __future__ import annotations
from typing import TYPE_CHECKING

from pydantic.v1 import AnyUrl
from typing import List, Optional, Union


from pydantic.v1 import Field
from pydantic2_schemaorg.Intangible import Intangible


class ConstraintNode(Intangible):
    """The ConstraintNode type is provided to support usecases in which a node in a structured data graph is described
     with properties which appear to describe a single entity, but are being used in a situation where they serve
     a more abstract purpose. A [[ConstraintNode]] can be described using [[constraintProperty]] and [[numConstraints]].
     These constraint properties can serve a variety of purposes, and their values may sometimes be understood
     to indicate sets of possible values rather than single, exact and specific values.

    See: https://schema.org/ConstraintNode
    Model depth: 3
    """

    type_: str = Field(default="ConstraintNode", alias="@type", const=True)
    constraintProperty: Optional[
        Union[
            List[Union[AnyUrl, "URL", "Property", str]], AnyUrl, "URL", "Property", str
        ]
    ] = Field(
        default=None,
        description="Indicates a property used as a constraint. For example, in the definition of a [[StatisticalVariable]]. The value is a property, either from within Schema.org or from other compatible (e.g. RDF) systems such as DataCommons.org or Wikidata.org.",
    )
    numConstraints: Optional[
        Union[List[Union[int, "Integer", str]], int, "Integer", str]
    ] = Field(
        default=None,
        description="Indicates the number of constraints property values defined for a particular [[ConstraintNode]] such as [[StatisticalVariable]]. This helps applications understand if they have access to a sufficiently complete description of a [[StatisticalVariable]] or other construct that is defined using properties on template-style nodes.",
    )


if TYPE_CHECKING:
    from pydantic2_schemaorg.URL import URL
    from pydantic2_schemaorg.Property import Property
    from pydantic2_schemaorg.Integer import Integer



from __future__ import annotations


from pydantic.v1 import Field
from pydantic2_schemaorg.Enumeration import Enumeration


class MediaEnumeration(Enumeration):
    """MediaEnumeration enumerations are lists of codes, labels etc. useful for describing media objects. They
     may be reflections of externally developed lists, or created at schema.org, or a combination.

    See: https://schema.org/MediaEnumeration
    Model depth: 4
    """

    type_: str = Field(default="MediaEnumeration", alias="@type", const=True)



from __future__ import annotations


from pydantic.v1 import Field
from pydantic2_schemaorg.BodyMeasurementTypeEnumeration import (
    BodyMeasurementTypeEnumeration,
)


class BodyMeasurementArm(BodyMeasurementTypeEnumeration):
    """Arm length (measured between arms/shoulder line intersection and the prominent wrist bone). Used, for example,
     to fit shirts.

    See: https://schema.org/BodyMeasurementArm
    Model depth: 6
    """

    type_: str = Field(default="BodyMeasurementArm", alias="@type", const=True)



from __future__ import annotations
from typing import TYPE_CHECKING

from pydantic.v1 import AnyUrl
from typing import List, Optional, Union


from pydantic.v1 import Field
from pydantic2_schemaorg.ConstraintNode import ConstraintNode


class StatisticalVariable(ConstraintNode):
    """[[StatisticalVariable]] represents any type of statistical metric that can be measured at a place and time.
     The usage pattern for [[StatisticalVariable]] is typically expressed using [[Observation]] with an explicit
     [[populationType]], which is a type, typically drawn from Schema.org. Each [[StatisticalVariable]] is
     marked as a [[ConstraintNode]], meaning that some properties (those listed using [[constraintProperty]])
     serve in this setting solely to define the statistical variable rather than literally describe a specific
     person, place or thing. For example, a [[StatisticalVariable]] Median_Height_Person_Female representing
     the median height of women, could be written as follows: the population type is [[Person]]; the measuredProperty
     [[height]]; the [[statType]] [[median]]; the [[gender]] [[Female]]. It is important to note that there
     are many kinds of scientific quantitative observation which are not fully, perfectly or unambiguously described
     following this pattern, or with solely Schema.org terminology. The approach taken here is designed to allow
     partial, incremental or minimal description of [[StatisticalVariable]]s, and the use of detailed sets
     of entity and property IDs from external repositories. The [[measurementMethod]], [[unitCode]] and [[unitText]]
     properties can also be used to clarify the specific nature and notation of an observed measurement.

    See: https://schema.org/StatisticalVariable
    Model depth: 4
    """

    type_: str = Field(default="StatisticalVariable", alias="@type", const=True)
    measurementTechnique: Optional[
        Union[
            List[
                Union[
                    AnyUrl, "URL", str, "Text", "MeasurementMethodEnum", "DefinedTerm"
                ]
            ],
            AnyUrl,
            "URL",
            str,
            "Text",
            "MeasurementMethodEnum",
            "DefinedTerm",
        ]
    ] = Field(
        default=None,
        description='A technique, method or technology used in an [[Observation]], [[StatisticalVariable]] or [[Dataset]] (or [[DataDownload]], [[DataCatalog]]), corresponding to the method used for measuring the corresponding variable(s) (for datasets, described using [[variableMeasured]]; for [[Observation]], a [[StatisticalVariable]]). Often but not necessarily each [[variableMeasured]] will have an explicit representation as (or mapping to) an property such as those defined in Schema.org, or other RDF vocabularies and "knowledge graphs". In that case the subproperty of [[variableMeasured]] called [[measuredProperty]] is applicable. The [[measurementTechnique]] property helps when extra clarification is needed about how a [[measuredProperty]] was measured. This is oriented towards scientific and scholarly dataset publication but may have broader applicability; it is not intended as a full representation of measurement, but can often serve as a high level summary for dataset discovery. For example, if [[variableMeasured]] is: molecule concentration, [[measurementTechnique]] could be: "mass spectrometry" or "nmr spectroscopy" or "colorimetry" or "immunofluorescence". If the [[variableMeasured]] is "depression rating", the [[measurementTechnique]] could be "Zung Scale" or "HAM-D" or "Beck Depression Inventory". If there are several [[variableMeasured]] properties recorded for some given data object, use a [[PropertyValue]] for each [[variableMeasured]] and attach the corresponding [[measurementTechnique]]. The value can also be from an enumeration, organized as a [[MeasurementMetholdEnumeration]].',
    )
    populationType: Optional[Union[List[Union["Class", str]], "Class", str]] = Field(
        default=None,
        description="Indicates the populationType common to all members of a [[StatisticalPopulation]] or all cases within the scope of a [[StatisticalVariable]].",
    )
    measurementDenominator: Optional[
        Union[List[Union["StatisticalVariable", str]], "StatisticalVariable", str]
    ] = Field(
        default=None,
        description="Identifies the denominator variable when an observation represents a ratio or percentage.",
    )
    measurementQualifier: Optional[
        Union[List[Union["Enumeration", str]], "Enumeration", str]
    ] = Field(
        default=None,
        description="Provides additional qualification to an observation. For example, a GDP observation measures the Nominal value.",
    )
    statType: Optional[
        Union[
            List[Union[AnyUrl, "URL", str, "Text", "Property"]],
            AnyUrl,
            "URL",
            str,
            "Text",
            "Property",
        ]
    ] = Field(
        default=None,
        description="Indicates the kind of statistic represented by a [[StatisticalVariable]], e.g. mean, count etc. The value of statType is a property, either from within Schema.org (e.g. [[median]], [[marginOfError]], [[maxValue]], [[minValue]]) or from other compatible (e.g. RDF) systems such as DataCommons.org or Wikidata.org.",
    )
    measurementMethod: Optional[
        Union[
            List[
                Union[
                    AnyUrl, "URL", str, "Text", "MeasurementMethodEnum", "DefinedTerm"
                ]
            ],
            AnyUrl,
            "URL",
            str,
            "Text",
            "MeasurementMethodEnum",
            "DefinedTerm",
        ]
    ] = Field(
        default=None,
        description="A subproperty of [[measurementTechnique]] that can be used for specifying specific methods, in particular via [[MeasurementMethodEnum]].",
    )
    measuredProperty: Optional[Union[List[Union["Property", str]], "Property", str]] = (
        Field(
            default=None,
            description="The measuredProperty of an [[Observation]], typically via its [[StatisticalVariable]]. There are various kinds of applicable [[Property]]: a schema.org property, a property from other RDF-compatible systems, e.g. W3C RDF Data Cube, Data Commons, Wikidata, or schema.org extensions such as [GS1's](https://www.gs1.org/voc/?show=properties).",
        )
    )


if TYPE_CHECKING:
    from pydantic2_schemaorg.URL import URL
    from pydantic2_schemaorg.Text import Text
    from pydantic2_schemaorg.MeasurementMethodEnum import MeasurementMethodEnum
    from pydantic2_schemaorg.DefinedTerm import DefinedTerm
    from pydantic2_schemaorg.Class import Class
    from pydantic2_schemaorg.Enumeration import Enumeration
    from pydantic2_schemaorg.Property import Property



from __future__ import annotations
from typing import TYPE_CHECKING

from datetime import date, datetime
from typing import List, Optional, Union
from pydantic.v1 import AnyUrl


from pydantic.v1 import Field
from pydantic2_schemaorg.CreativeWork import CreativeWork


class Certification(CreativeWork):
    """A Certification is an official and authoritative statement about a subject, for example a product, service,
     person, or organization. A certification is typically issued by an indendent certification body, for example
     a professional organization or government. It formally attests certain characteristics about the subject,
     for example Organizations can be ISO certified, Food products can be certified Organic or Vegan, a Person
     can be a certified professional, a Place can be certified for food processing. There are certifications for
     many domains: regulatory, organizational, recycling, food, efficiency, educational, ecological, etc.
     A certification is a form of credential, as are accreditations and licenses. Mapped from the [gs1:CertificationDetails](https://www.gs1.org/voc/CertificationDetails)
     class in the GS1 Web Vocabulary.

    See: https://schema.org/Certification
    Model depth: 3
    """

    type_: str = Field(default="Certification", alias="@type", const=True)
    datePublished: Optional[
        Union[
            List[Union[datetime, "DateTime", date, "Date", str]],
            datetime,
            "DateTime",
            date,
            "Date",
            str,
        ]
    ] = Field(
        default=None,
        description="Date of first publication or broadcast. For example the date a [[CreativeWork]] was broadcast or a [[Certification]] was issued.",
    )
    auditDate: Optional[
        Union[
            List[Union[datetime, "DateTime", date, "Date", str]],
            datetime,
            "DateTime",
            date,
            "Date",
            str,
        ]
    ] = Field(
        default=None,
        description="Date when a certification was last audited. See also [gs1:certificationAuditDate](https://www.gs1.org/voc/certificationAuditDate).",
    )
    certificationRating: Optional[Union[List[Union["Rating", str]], "Rating", str]] = (
        Field(
            default=None,
            description="Rating of a certification instance (as defined by an independent certification body). Typically this rating can be used to rate the level to which the requirements of the certification instance are fulfilled. See also [gs1:certificationValue](https://www.gs1.org/voc/certificationValue).",
        )
    )
    validIn: Optional[
        Union[List[Union["AdministrativeArea", str]], "AdministrativeArea", str]
    ] = Field(
        default=None,
        description="The geographic area where the item is valid. Applies for example to a [[Permit]], a [[Certification]], or an [[EducationalOccupationalCredential]].",
    )
    validFrom: Optional[
        Union[
            List[Union[datetime, "DateTime", date, "Date", str]],
            datetime,
            "DateTime",
            date,
            "Date",
            str,
        ]
    ] = Field(
        default=None,
        description="The date when the item becomes valid.",
    )
    certificationIdentification: Optional[
        Union[List[Union[str, "Text", "DefinedTerm"]], str, "Text", "DefinedTerm"]
    ] = Field(
        default=None,
        description="Identifier of a certification instance (as registered with an independent certification body). Typically this identifier can be used to consult and verify the certification instance. See also [gs1:certificationIdentification](https://www.gs1.org/voc/certificationIdentification).",
    )
    logo: Optional[
        Union[
            List[Union[AnyUrl, "URL", "ImageObject", str]],
            AnyUrl,
            "URL",
            "ImageObject",
            str,
        ]
    ] = Field(
        default=None,
        description="An associated logo.",
    )
    about: Optional[Union[List[Union["Thing", str]], "Thing", str]] = Field(
        default=None,
        description="The subject matter of the content.",
    )
    hasMeasurement: Optional[
        Union[List[Union["QuantitativeValue", str]], "QuantitativeValue", str]
    ] = Field(
        default=None,
        description="A measurement of an item, For example, the inseam of pants, the wheel size of a bicycle, the gauge of a screw, or the carbon footprint measured for certification by an authority. Usually an exact measurement, but can also be a range of measurements for adjustable products, for example belts and ski bindings.",
    )
    issuedBy: Optional[Union[List[Union["Organization", str]], "Organization", str]] = (
        Field(
            default=None,
            description="The organization issuing the item, for example a [[Permit]], [[Ticket]], or [[Certification]].",
        )
    )
    certificationStatus: Optional[
        Union[
            List[Union["CertificationStatusEnumeration", str]],
            "CertificationStatusEnumeration",
            str,
        ]
    ] = Field(
        default=None,
        description="Indicates the current status of a certification: active or inactive. See also [gs1:certificationStatus](https://www.gs1.org/voc/certificationStatus).",
    )
    expires: Optional[
        Union[
            List[Union[datetime, "DateTime", date, "Date", str]],
            datetime,
            "DateTime",
            date,
            "Date",
            str,
        ]
    ] = Field(
        default=None,
        description="Date the content expires and is no longer useful or available. For example a [[VideoObject]] or [[NewsArticle]] whose availability or relevance is time-limited, a [[ClaimReview]] fact check whose publisher wants to indicate that it may no longer be relevant (or helpful to highlight) after some date, or a [[Certification]] the validity has expired.",
    )


if TYPE_CHECKING:
    from pydantic2_schemaorg.DateTime import DateTime
    from pydantic2_schemaorg.Date import Date
    from pydantic2_schemaorg.Rating import Rating
    from pydantic2_schemaorg.AdministrativeArea import AdministrativeArea
    from pydantic2_schemaorg.Text import Text
    from pydantic2_schemaorg.DefinedTerm import DefinedTerm
    from pydantic2_schemaorg.URL import URL
    from pydantic2_schemaorg.ImageObject import ImageObject
    from pydantic2_schemaorg.Thing import Thing
    from pydantic2_schemaorg.QuantitativeValue import QuantitativeValue
    from pydantic2_schemaorg.Organization import Organization
    from pydantic2_schemaorg.CertificationStatusEnumeration import (
        CertificationStatusEnumeration,
    )



from __future__ import annotations


from pydantic.v1 import Field
from pydantic2_schemaorg.RestrictedDiet import RestrictedDiet


class GlutenFreeDiet(RestrictedDiet):
    """A diet exclusive of gluten.

    See: https://schema.org/GlutenFreeDiet
    Model depth: 5
    """

    type_: str = Field(default="GlutenFreeDiet", alias="@type", const=True)



from __future__ import annotations


from pydantic.v1 import Field
from pydantic2_schemaorg.CollectionPage import CollectionPage


class MediaGallery(CollectionPage):
    """Web page type: Media gallery page. A mixed-media page that can contain media such as images, videos, and other
     multimedia.

    See: https://schema.org/MediaGallery
    Model depth: 5
    """

    type_: str = Field(default="MediaGallery", alias="@type", const=True)



from __future__ import annotations


from pydantic.v1 import Field
from pydantic2_schemaorg.MedicalTherapy import MedicalTherapy
from pydantic2_schemaorg.MedicalProcedure import MedicalProcedure


class PalliativeProcedure(MedicalTherapy, MedicalProcedure):
    """A medical procedure intended primarily for palliative purposes, aimed at relieving the symptoms of an underlying
     health condition.

    See: https://schema.org/PalliativeProcedure
    Model depth: 4
    """

    type_: str = Field(default="PalliativeProcedure", alias="@type", const=True)



from __future__ import annotations


from pydantic.v1 import Field
from pydantic2_schemaorg.Store import Store
from pydantic2_schemaorg.AutomotiveBusiness import AutomotiveBusiness


class AutoPartsStore(Store, AutomotiveBusiness):
    """An auto parts store.

    See: https://schema.org/AutoPartsStore
    Model depth: 5
    """

    type_: str = Field(default="AutoPartsStore", alias="@type", const=True)



from __future__ import annotations


from pydantic.v1 import Field
from pydantic2_schemaorg.Article import Article


class ScholarlyArticle(Article):
    """A scholarly article.

    See: https://schema.org/ScholarlyArticle
    Model depth: 4
    """

    type_: str = Field(default="ScholarlyArticle", alias="@type", const=True)



from __future__ import annotations
from typing import TYPE_CHECKING

from typing import List, Optional, Union


from pydantic.v1 import Field
from pydantic2_schemaorg.CreativeWork import CreativeWork


class HowTo(CreativeWork):
    """Instructions that explain how to achieve a result by performing a sequence of steps.

    See: https://schema.org/HowTo
    Model depth: 3
    """

    type_: str = Field(default="HowTo", alias="@type", const=True)
    supply: Optional[
        Union[List[Union[str, "Text", "HowToSupply"]], str, "Text", "HowToSupply"]
    ] = Field(
        default=None,
        description="A sub-property of instrument. A supply consumed when performing instructions or a direction.",
    )
    yield_: Optional[
        Union[
            List[Union[str, "Text", "QuantitativeValue"]],
            str,
            "Text",
            "QuantitativeValue",
        ]
    ] = Field(
        default=None,
        alias="yield",
        description="The quantity that results by performing instructions. For example, a paper airplane, 10 personalized candles.",
    )
    totalTime: Optional[Union[List[Union["Duration", str]], "Duration", str]] = Field(
        default=None,
        description="The total time required to perform instructions or a direction (including time to prepare the supplies), in [ISO 8601 duration format](http://en.wikipedia.org/wiki/ISO_8601).",
    )
    step: Optional[
        Union[
            List[Union[str, "Text", "HowToSection", "HowToStep", "CreativeWork"]],
            str,
            "Text",
            "HowToSection",
            "HowToStep",
            "CreativeWork",
        ]
    ] = Field(
        default=None,
        description="A single step item (as HowToStep, text, document, video, etc.) or a HowToSection.",
    )
    estimatedCost: Optional[
        Union[List[Union[str, "Text", "MonetaryAmount"]], str, "Text", "MonetaryAmount"]
    ] = Field(
        default=None,
        description="The estimated cost of the supply or supplies consumed when performing instructions.",
    )
    prepTime: Optional[Union[List[Union["Duration", str]], "Duration", str]] = Field(
        default=None,
        description="The length of time it takes to prepare the items to be used in instructions or a direction, in [ISO 8601 duration format](http://en.wikipedia.org/wiki/ISO_8601).",
    )
    performTime: Optional[Union[List[Union["Duration", str]], "Duration", str]] = Field(
        default=None,
        description="The length of time it takes to perform instructions or a direction (not including time to prepare the supplies), in [ISO 8601 duration format](http://en.wikipedia.org/wiki/ISO_8601).",
    )
    steps: Optional[
        Union[
            List[Union[str, "Text", "ItemList", "CreativeWork"]],
            str,
            "Text",
            "ItemList",
            "CreativeWork",
        ]
    ] = Field(
        default=None,
        description="A single step item (as HowToStep, text, document, video, etc.) or a HowToSection (originally misnamed 'steps'; 'step' is preferred).",
    )
    tool: Optional[
        Union[List[Union[str, "Text", "HowToTool"]], str, "Text", "HowToTool"]
    ] = Field(
        default=None,
        description="A sub property of instrument. An object used (but not consumed) when performing instructions or a direction.",
    )


if TYPE_CHECKING:
    from pydantic2_schemaorg.Text import Text
    from pydantic2_schemaorg.HowToSupply import HowToSupply
    from pydantic2_schemaorg.QuantitativeValue import QuantitativeValue
    from pydantic2_schemaorg.Duration import Duration
    from pydantic2_schemaorg.HowToSection import HowToSection
    from pydantic2_schemaorg.HowToStep import HowToStep
    from pydantic2_schemaorg.CreativeWork import CreativeWork
    from pydantic2_schemaorg.MonetaryAmount import MonetaryAmount
    from pydantic2_schemaorg.ItemList import ItemList
    from pydantic2_schemaorg.HowToTool import HowToTool



from __future__ import annotations
from typing import TYPE_CHECKING

from typing import List, Optional, Union


from pydantic.v1 import Field
from pydantic2_schemaorg.CreativeWork import CreativeWork


class Quotation(CreativeWork):
    """A quotation. Often but not necessarily from some written work, attributable to a real world author and - if
     associated with a fictional character - to any fictional Person. Use [[isBasedOn]] to link to source/origin.
     The [[recordedIn]] property can be used to reference a Quotation from an [[Event]].

    See: https://schema.org/Quotation
    Model depth: 3
    """

    type_: str = Field(default="Quotation", alias="@type", const=True)
    spokenByCharacter: Optional[
        Union[List[Union["Person", "Organization", str]], "Person", "Organization", str]
    ] = Field(
        default=None,
        description="The (e.g. fictional) character, Person or Organization to whom the quotation is attributed within the containing CreativeWork.",
    )


if TYPE_CHECKING:
    from pydantic2_schemaorg.Person import Person
    from pydantic2_schemaorg.Organization import Organization



from __future__ import annotations
from typing import TYPE_CHECKING

from typing import List, Optional, Union


from pydantic.v1 import Field
from pydantic2_schemaorg.MedicalEntity import MedicalEntity


class MedicalRiskEstimator(MedicalEntity):
    """Any rule set or interactive tool for estimating the risk of developing a complication or condition.

    See: https://schema.org/MedicalRiskEstimator
    Model depth: 3
    """

    type_: str = Field(default="MedicalRiskEstimator", alias="@type", const=True)
    estimatesRiskOf: Optional[
        Union[List[Union["MedicalEntity", str]], "MedicalEntity", str]
    ] = Field(
        default=None,
        description="The condition, complication, or symptom whose risk is being estimated.",
    )
    includedRiskFactor: Optional[
        Union[List[Union["MedicalRiskFactor", str]], "MedicalRiskFactor", str]
    ] = Field(
        default=None,
        description="A modifiable or non-modifiable risk factor included in the calculation, e.g. age, coexisting condition.",
    )


if TYPE_CHECKING:
    from pydantic2_schemaorg.MedicalEntity import MedicalEntity
    from pydantic2_schemaorg.MedicalRiskFactor import MedicalRiskFactor



from __future__ import annotations


from pydantic.v1 import Field
from pydantic2_schemaorg.MedicalTrialDesign import MedicalTrialDesign


class SingleCenterTrial(MedicalTrialDesign):
    """A trial that takes place at a single center.

    See: https://schema.org/SingleCenterTrial
    Model depth: 6
    """

    type_: str = Field(default="SingleCenterTrial", alias="@type", const=True)



from __future__ import annotations
from typing import TYPE_CHECKING

from pydantic.v1 import AnyUrl, StrictBool
from typing import List, Optional, Union


from pydantic.v1 import Field
from pydantic2_schemaorg.LocalBusiness import LocalBusiness


class FoodEstablishment(LocalBusiness):
    """A food-related business.

    See: https://schema.org/FoodEstablishment
    Model depth: 4
    """

    type_: str = Field(default="FoodEstablishment", alias="@type", const=True)
    acceptsReservations: Optional[
        Union[
            List[Union[AnyUrl, "URL", StrictBool, "Boolean", str, "Text"]],
            AnyUrl,
            "URL",
            StrictBool,
            "Boolean",
            str,
            "Text",
        ]
    ] = Field(
        default=None,
        description="Indicates whether a FoodEstablishment accepts reservations. Values can be Boolean, an URL at which reservations can be made or (for backwards compatibility) the strings ```Yes``` or ```No```.",
    )
    servesCuisine: Optional[Union[List[Union[str, "Text"]], str, "Text"]] = Field(
        default=None,
        description="The cuisine of the restaurant.",
    )
    starRating: Optional[Union[List[Union["Rating", str]], "Rating", str]] = Field(
        default=None,
        description="An official rating for a lodging business or food establishment, e.g. from national associations or standards bodies. Use the author property to indicate the rating organization, e.g. as an Organization with name such as (e.g. HOTREC, DEHOGA, WHR, or Hotelstars).",
    )
    hasMenu: Optional[
        Union[
            List[Union[AnyUrl, "URL", str, "Text", "Menu"]],
            AnyUrl,
            "URL",
            str,
            "Text",
            "Menu",
        ]
    ] = Field(
        default=None,
        description="Either the actual menu as a structured representation, as text, or a URL of the menu.",
    )
    menu: Optional[
        Union[
            List[Union[AnyUrl, "URL", str, "Text", "Menu"]],
            AnyUrl,
            "URL",
            str,
            "Text",
            "Menu",
        ]
    ] = Field(
        default=None,
        description="Either the actual menu as a structured representation, as text, or a URL of the menu.",
    )


if TYPE_CHECKING:
    from pydantic2_schemaorg.URL import URL
    from pydantic2_schemaorg.Boolean import Boolean
    from pydantic2_schemaorg.Text import Text
    from pydantic2_schemaorg.Rating import Rating
    from pydantic2_schemaorg.Menu import Menu



from __future__ import annotations


from pydantic.v1 import Field
from pydantic2_schemaorg.LegalValueLevel import LegalValueLevel


class UnofficialLegalValue(LegalValueLevel):
    """Indicates that a document has no particular or special standing (e.g. a republication of a law by a private
     publisher).

    See: https://schema.org/UnofficialLegalValue
    Model depth: 5
    """

    type_: str = Field(default="UnofficialLegalValue", alias="@type", const=True)



from __future__ import annotations
from typing import TYPE_CHECKING

from typing import List, Optional, Union


from pydantic.v1 import Field
from pydantic2_schemaorg.MedicalEntity import MedicalEntity


class MedicalStudy(MedicalEntity):
    """A medical study is an umbrella type covering all kinds of research studies relating to human medicine or health,
     including observational studies and interventional trials and registries, randomized, controlled or
     not. When the specific type of study is known, use one of the extensions of this type, such as MedicalTrial or
     MedicalObservationalStudy. Also, note that this type should be used to mark up data that describes the study
     itself; to tag an article that publishes the results of a study, use MedicalScholarlyArticle. Note: use the
     code property of MedicalEntity to store study IDs, e.g. clinicaltrials.gov ID.

    See: https://schema.org/MedicalStudy
    Model depth: 3
    """

    type_: str = Field(default="MedicalStudy", alias="@type", const=True)
    healthCondition: Optional[
        Union[List[Union["MedicalCondition", str]], "MedicalCondition", str]
    ] = Field(
        default=None,
        description="Specifying the health condition(s) of a patient, medical study, or other target audience.",
    )
    studyLocation: Optional[
        Union[List[Union["AdministrativeArea", str]], "AdministrativeArea", str]
    ] = Field(
        default=None,
        description="The location in which the study is taking/took place.",
    )
    sponsor: Optional[
        Union[List[Union["Person", "Organization", str]], "Person", "Organization", str]
    ] = Field(
        default=None,
        description="A person or organization that supports a thing through a pledge, promise, or financial contribution. E.g. a sponsor of a Medical Study or a corporate sponsor of an event.",
    )
    studySubject: Optional[
        Union[List[Union["MedicalEntity", str]], "MedicalEntity", str]
    ] = Field(
        default=None,
        description="A subject of the study, i.e. one of the medical conditions, therapies, devices, drugs, etc. investigated by the study.",
    )
    status: Optional[
        Union[
            List[Union[str, "Text", "EventStatusType", "MedicalStudyStatus"]],
            str,
            "Text",
            "EventStatusType",
            "MedicalStudyStatus",
        ]
    ] = Field(
        default=None,
        description="The status of the study (enumerated).",
    )


if TYPE_CHECKING:
    from pydantic2_schemaorg.MedicalCondition import MedicalCondition
    from pydantic2_schemaorg.AdministrativeArea import AdministrativeArea
    from pydantic2_schemaorg.Person import Person
    from pydantic2_schemaorg.Organization import Organization
    from pydantic2_schemaorg.MedicalEntity import MedicalEntity
    from pydantic2_schemaorg.Text import Text
    from pydantic2_schemaorg.EventStatusType import EventStatusType
    from pydantic2_schemaorg.MedicalStudyStatus import MedicalStudyStatus



from __future__ import annotations


from pydantic.v1 import Field
from pydantic2_schemaorg.USNonprofitType import USNonprofitType


class Nonprofit501c3(USNonprofitType):
    """Nonprofit501c3: Non-profit type referring to Religious, Educational, Charitable, Scientific, Literary,
     Testing for Public Safety, Fostering National or International Amateur Sports Competition, or Prevention
     of Cruelty to Children or Animals Organizations.

    See: https://schema.org/Nonprofit501c3
    Model depth: 6
    """

    type_: str = Field(default="Nonprofit501c3", alias="@type", const=True)



from __future__ import annotations


from pydantic.v1 import Field
from pydantic2_schemaorg.MedicalTrialDesign import MedicalTrialDesign


class DoubleBlindedTrial(MedicalTrialDesign):
    """A trial design in which neither the researcher nor the patient knows the details of the treatment the patient
     was randomly assigned to.

    See: https://schema.org/DoubleBlindedTrial
    Model depth: 6
    """

    type_: str = Field(default="DoubleBlindedTrial", alias="@type", const=True)



from __future__ import annotations


from pydantic.v1 import Field
from pydantic2_schemaorg.PhysicalExam import PhysicalExam


class Throat(PhysicalExam):
    """Throat assessment with clinical examination.

    See: https://schema.org/Throat
    Model depth: 5
    """

    type_: str = Field(default="Throat", alias="@type", const=True)



from __future__ import annotations


from pydantic.v1 import Field
from pydantic2_schemaorg.MedicalSpecialty import MedicalSpecialty


class Infectious(MedicalSpecialty):
    """Something in medical science that pertains to infectious diseases, i.e. caused by bacterial, viral, fungal
     or parasitic infections.

    See: https://schema.org/Infectious
    Model depth: 6
    """

    type_: str = Field(default="Infectious", alias="@type", const=True)



from __future__ import annotations


from pydantic.v1 import Field
from pydantic2_schemaorg.PerformingGroup import PerformingGroup


class TheaterGroup(PerformingGroup):
    """A theater group or company, for example, the Royal Shakespeare Company or Druid Theatre.

    See: https://schema.org/TheaterGroup
    Model depth: 4
    """

    type_: str = Field(default="TheaterGroup", alias="@type", const=True)



from __future__ import annotations
from typing import TYPE_CHECKING

from pydantic.v1 import StrictInt, StrictFloat
from typing import List, Optional, Union


from pydantic.v1 import Field
from pydantic2_schemaorg.MedicalIntangible import MedicalIntangible


class MedicalConditionStage(MedicalIntangible):
    """A stage of a medical condition, such as 'Stage IIIa'.

    See: https://schema.org/MedicalConditionStage
    Model depth: 4
    """

    type_: str = Field(default="MedicalConditionStage", alias="@type", const=True)
    stageAsNumber: Optional[
        Union[
            List[Union[StrictInt, StrictFloat, "Number", str]],
            StrictInt,
            StrictFloat,
            "Number",
            str,
        ]
    ] = Field(
        default=None,
        description="The stage represented as a number, e.g. 3.",
    )
    subStageSuffix: Optional[Union[List[Union[str, "Text"]], str, "Text"]] = Field(
        default=None,
        description="The substage, e.g. 'a' for Stage IIIa.",
    )


if TYPE_CHECKING:
    from pydantic2_schemaorg.Number import Number
    from pydantic2_schemaorg.Text import Text



from __future__ import annotations
from typing import TYPE_CHECKING

from typing import List, Optional, Union


from pydantic.v1 import Field
from pydantic2_schemaorg.CreativeWork import CreativeWork


class Review(CreativeWork):
    """A review of an item - for example, of a restaurant, movie, or store.

    See: https://schema.org/Review
    Model depth: 3
    """

    type_: str = Field(default="Review", alias="@type", const=True)
    associatedReview: Optional[Union[List[Union["Review", str]], "Review", str]] = (
        Field(
            default=None,
            description="An associated [[Review]].",
        )
    )
    negativeNotes: Optional[
        Union[
            List[Union[str, "Text", "ListItem", "ItemList", "WebContent"]],
            str,
            "Text",
            "ListItem",
            "ItemList",
            "WebContent",
        ]
    ] = Field(
        default=None,
        description="Provides negative considerations regarding something, most typically in pro/con lists for reviews (alongside [[positiveNotes]]). For symmetry In the case of a [[Review]], the property describes the [[itemReviewed]] from the perspective of the review; in the case of a [[Product]], the product itself is being described. Since product descriptions tend to emphasise positive claims, it may be relatively unusual to find [[negativeNotes]] used in this way. Nevertheless for the sake of symmetry, [[negativeNotes]] can be used on [[Product]]. The property values can be expressed either as unstructured text (repeated as necessary), or if ordered, as a list (in which case the most negative is at the beginning of the list).",
    )
    associatedMediaReview: Optional[
        Union[List[Union["Review", str]], "Review", str]
    ] = Field(
        default=None,
        description="An associated [[MediaReview]], related by specific common content, topic or claim. The expectation is that this property would be most typically used in cases where a single activity is conducting both claim reviews and media reviews, in which case [[relatedMediaReview]] would commonly be used on a [[ClaimReview]], while [[relatedClaimReview]] would be used on [[MediaReview]].",
    )
    reviewBody: Optional[Union[List[Union[str, "Text"]], str, "Text"]] = Field(
        default=None,
        description="The actual body of the review.",
    )
    positiveNotes: Optional[
        Union[
            List[Union[str, "Text", "ListItem", "ItemList", "WebContent"]],
            str,
            "Text",
            "ListItem",
            "ItemList",
            "WebContent",
        ]
    ] = Field(
        default=None,
        description="Provides positive considerations regarding something, for example product highlights or (alongside [[negativeNotes]]) pro/con lists for reviews. In the case of a [[Review]], the property describes the [[itemReviewed]] from the perspective of the review; in the case of a [[Product]], the product itself is being described. The property values can be expressed either as unstructured text (repeated as necessary), or if ordered, as a list (in which case the most positive is at the beginning of the list).",
    )
    associatedClaimReview: Optional[
        Union[List[Union["Review", str]], "Review", str]
    ] = Field(
        default=None,
        description="An associated [[ClaimReview]], related by specific common content, topic or claim. The expectation is that this property would be most typically used in cases where a single activity is conducting both claim reviews and media reviews, in which case [[relatedMediaReview]] would commonly be used on a [[ClaimReview]], while [[relatedClaimReview]] would be used on [[MediaReview]].",
    )
    reviewAspect: Optional[Union[List[Union[str, "Text"]], str, "Text"]] = Field(
        default=None,
        description="This Review or Rating is relevant to this part or facet of the itemReviewed.",
    )
    reviewRating: Optional[Union[List[Union["Rating", str]], "Rating", str]] = Field(
        default=None,
        description="The rating given in this review. Note that reviews can themselves be rated. The ```reviewRating``` applies to rating given by the review. The [[aggregateRating]] property applies to the review itself, as a creative work.",
    )
    itemReviewed: Optional[Union[List[Union["Thing", str]], "Thing", str]] = Field(
        default=None,
        description="The item that is being reviewed/rated.",
    )


if TYPE_CHECKING:
    from pydantic2_schemaorg.Text import Text
    from pydantic2_schemaorg.ListItem import ListItem
    from pydantic2_schemaorg.ItemList import ItemList
    from pydantic2_schemaorg.WebContent import WebContent
    from pydantic2_schemaorg.Rating import Rating
    from pydantic2_schemaorg.Thing import Thing



from __future__ import annotations


from pydantic.v1 import Field
from pydantic2_schemaorg.CivicStructure import CivicStructure


class PerformingArtsTheater(CivicStructure):
    """A theater or other performing art center.

    See: https://schema.org/PerformingArtsTheater
    Model depth: 4
    """

    type_: str = Field(default="PerformingArtsTheater", alias="@type", const=True)



from __future__ import annotations


from pydantic.v1 import Field
from pydantic2_schemaorg.LocalBusiness import LocalBusiness


class EntertainmentBusiness(LocalBusiness):
    """A business providing entertainment.

    See: https://schema.org/EntertainmentBusiness
    Model depth: 4
    """

    type_: str = Field(default="EntertainmentBusiness", alias="@type", const=True)



from __future__ import annotations
from typing import TYPE_CHECKING

from typing import List, Optional, Union


from pydantic.v1 import Field
from pydantic2_schemaorg.MedicalRiskEstimator import MedicalRiskEstimator


class MedicalRiskScore(MedicalRiskEstimator):
    """A simple system that adds up the number of risk factors to yield a score that is associated with prognosis, e.g.
     CHAD score, TIMI risk score.

    See: https://schema.org/MedicalRiskScore
    Model depth: 4
    """

    type_: str = Field(default="MedicalRiskScore", alias="@type", const=True)
    algorithm: Optional[Union[List[Union[str, "Text"]], str, "Text"]] = Field(
        default=None,
        description="The algorithm or rules to follow to compute the score.",
    )


if TYPE_CHECKING:
    from pydantic2_schemaorg.Text import Text



from __future__ import annotations
from typing import TYPE_CHECKING

from typing import List, Optional, Union
from pydantic.v1 import AnyUrl


from pydantic.v1 import Field
from pydantic2_schemaorg.LifestyleModification import LifestyleModification


class PhysicalActivity(LifestyleModification):
    """Any bodily activity that enhances or maintains physical fitness and overall health and wellness. Includes
     activity that is part of daily living and routine, structured exercise, and exercise prescribed as part of
     a medical treatment or recovery plan.

    See: https://schema.org/PhysicalActivity
    Model depth: 4
    """

    type_: str = Field(default="PhysicalActivity", alias="@type", const=True)
    pathophysiology: Optional[Union[List[Union[str, "Text"]], str, "Text"]] = Field(
        default=None,
        description="Changes in the normal mechanical, physical, and biochemical functions that are associated with this activity or condition.",
    )
    epidemiology: Optional[Union[List[Union[str, "Text"]], str, "Text"]] = Field(
        default=None,
        description="The characteristics of associated patients, such as age, gender, race etc.",
    )
    category: Optional[
        Union[
            List[
                Union[
                    AnyUrl,
                    "URL",
                    str,
                    "Text",
                    "PhysicalActivityCategory",
                    "CategoryCode",
                    "Thing",
                ]
            ],
            AnyUrl,
            "URL",
            str,
            "Text",
            "PhysicalActivityCategory",
            "CategoryCode",
            "Thing",
        ]
    ] = Field(
        default=None,
        description="A category for the item. Greater signs or slashes can be used to informally indicate a category hierarchy.",
    )
    associatedAnatomy: Optional[
        Union[
            List[
                Union[
                    "SuperficialAnatomy", "AnatomicalSystem", "AnatomicalStructure", str
                ]
            ],
            "SuperficialAnatomy",
            "AnatomicalSystem",
            "AnatomicalStructure",
            str,
        ]
    ] = Field(
        default=None,
        description="The anatomy of the underlying organ system or structures associated with this entity.",
    )


if TYPE_CHECKING:
    from pydantic2_schemaorg.Text import Text
    from pydantic2_schemaorg.URL import URL
    from pydantic2_schemaorg.PhysicalActivityCategory import PhysicalActivityCategory
    from pydantic2_schemaorg.CategoryCode import CategoryCode
    from pydantic2_schemaorg.Thing import Thing
    from pydantic2_schemaorg.SuperficialAnatomy import SuperficialAnatomy
    from pydantic2_schemaorg.AnatomicalSystem import AnatomicalSystem
    from pydantic2_schemaorg.AnatomicalStructure import AnatomicalStructure



from __future__ import annotations


from pydantic.v1 import Field
from pydantic2_schemaorg.NLNonprofitType import NLNonprofitType


class NonprofitANBI(NLNonprofitType):
    """NonprofitANBI: Non-profit type referring to a Public Benefit Organization (NL).

    See: https://schema.org/NonprofitANBI
    Model depth: 6
    """

    type_: str = Field(default="NonprofitANBI", alias="@type", const=True)



from __future__ import annotations


from pydantic.v1 import Field
from pydantic2_schemaorg.EducationalOrganization import EducationalOrganization


class HighSchool(EducationalOrganization):
    """A high school.

    See: https://schema.org/HighSchool
    Model depth: 4
    """

    type_: str = Field(default="HighSchool", alias="@type", const=True)



from __future__ import annotations


from pydantic.v1 import Field
from pydantic2_schemaorg.PaymentMethodType import PaymentMethodType


class PhoneCarrierPayment(PaymentMethodType):
    """Payment by billing via the phone carrier.

    See: https://schema.org/PhoneCarrierPayment
    Model depth: 5
    """

    type_: str = Field(default="PhoneCarrierPayment", alias="@type", const=True)



from __future__ import annotations


from pydantic.v1 import Field
from pydantic2_schemaorg.MediaObject import MediaObject
from pydantic2_schemaorg.CreativeWork import CreativeWork


class AmpStory(MediaObject, CreativeWork):
    """A creative work with a visual storytelling format intended to be viewed online, particularly on mobile devices.

    See: https://schema.org/AmpStory
    Model depth: 3
    """

    type_: str = Field(default="AmpStory", alias="@type", const=True)



from __future__ import annotations


from pydantic.v1 import Field
from pydantic2_schemaorg.AdultOrientedEnumeration import AdultOrientedEnumeration


class NarcoticConsideration(AdultOrientedEnumeration):
    """Item is a narcotic as defined by the [1961 UN convention](https://www.incb.org/incb/en/narcotic-drugs/Yellowlist/yellow-list.html),
     for example marijuana or heroin.

    See: https://schema.org/NarcoticConsideration
    Model depth: 5
    """

    type_: str = Field(default="NarcoticConsideration", alias="@type", const=True)



from __future__ import annotations


from pydantic.v1 import Field
from pydantic2_schemaorg.Enumeration import Enumeration


class GameAvailabilityEnumeration(Enumeration):
    """For a [[VideoGame]], such as used with a [[PlayGameAction]], an enumeration of the kind of game availability
     offered.

    See: https://schema.org/GameAvailabilityEnumeration
    Model depth: 4
    """

    type_: str = Field(default="GameAvailabilityEnumeration", alias="@type", const=True)



from __future__ import annotations


from pydantic.v1 import Field
from pydantic2_schemaorg.CreativeWorkSeason import CreativeWorkSeason


class PodcastSeason(CreativeWorkSeason):
    """A single season of a podcast. Many podcasts do not break down into separate seasons. In that case, PodcastSeries
     should be used.

    See: https://schema.org/PodcastSeason
    Model depth: 4
    """

    type_: str = Field(default="PodcastSeason", alias="@type", const=True)



from __future__ import annotations
from typing import TYPE_CHECKING

from typing import List, Optional, Union


from pydantic.v1 import Field
from pydantic2_schemaorg.AudioObject import AudioObject
from pydantic2_schemaorg.Book import Book


class Audiobook(AudioObject, Book):
    """An audiobook.

    See: https://schema.org/Audiobook
    Model depth: 4
    """

    type_: str = Field(default="Audiobook", alias="@type", const=True)
    duration: Optional[Union[List[Union["Duration", str]], "Duration", str]] = Field(
        default=None,
        description="The duration of the item (movie, audio recording, event, etc.) in [ISO 8601 duration format](http://en.wikipedia.org/wiki/ISO_8601).",
    )
    readBy: Optional[Union[List[Union["Person", str]], "Person", str]] = Field(
        default=None,
        description="A person who reads (performs) the audiobook.",
    )


if TYPE_CHECKING:
    from pydantic2_schemaorg.Duration import Duration
    from pydantic2_schemaorg.Person import Person



from __future__ import annotations


from pydantic.v1 import Field
from pydantic2_schemaorg.MediaManipulationRatingEnumeration import (
    MediaManipulationRatingEnumeration,
)


class StagedContent(MediaManipulationRatingEnumeration):
    """Content coded 'staged content' in a [[MediaReview]], considered in the context of how it was published or
     shared. For a [[VideoObject]] to be 'staged content': A video that has been created using actors or similarly
     contrived. For an [[ImageObject]] to be 'staged content': An image that was created using actors or similarly
     contrived, such as a screenshot of a fake tweet. For an [[ImageObject]] with embedded text to be 'staged content':
     An image that was created using actors or similarly contrived, such as a screenshot of a fake tweet. For an [[AudioObject]]
     to be 'staged content': Audio that has been created using actors or similarly contrived.

    See: https://schema.org/StagedContent
    Model depth: 5
    """

    type_: str = Field(default="StagedContent", alias="@type", const=True)



from __future__ import annotations


from pydantic.v1 import Field
from pydantic2_schemaorg.MusicReleaseFormatType import MusicReleaseFormatType


class DVDFormat(MusicReleaseFormatType):
    """DVDFormat.

    See: https://schema.org/DVDFormat
    Model depth: 5
    """

    type_: str = Field(default="DVDFormat", alias="@type", const=True)



from __future__ import annotations


from pydantic.v1 import Field
from pydantic2_schemaorg.TierBenefitEnumeration import TierBenefitEnumeration


class TierBenefitLoyaltyPrice(TierBenefitEnumeration):
    """Benefit of the tier is a members-only price.

    See: https://schema.org/TierBenefitLoyaltyPrice
    Model depth: 5
    """

    type_: str = Field(default="TierBenefitLoyaltyPrice", alias="@type", const=True)



from __future__ import annotations
from typing import TYPE_CHECKING

from typing import List, Optional, Union
from pydantic.v1 import AnyUrl


from pydantic.v1 import Field
from pydantic2_schemaorg.StructuredValue import StructuredValue


class EngineSpecification(StructuredValue):
    """Information about the engine of the vehicle. A vehicle can have multiple engines represented by multiple
     engine specification entities.

    See: https://schema.org/EngineSpecification
    Model depth: 4
    """

    type_: str = Field(default="EngineSpecification", alias="@type", const=True)
    enginePower: Optional[
        Union[List[Union["QuantitativeValue", str]], "QuantitativeValue", str]
    ] = Field(
        default=None,
        description="The power of the vehicle's engine. Typical unit code(s): KWT for kilowatt, BHP for brake horsepower, N12 for metric horsepower (PS, with 1 PS = 735,49875 W) * Note 1: There are many different ways of measuring an engine's power. For an overview, see [http://en.wikipedia.org/wiki/Horsepower#Engine_power_test_codes](http://en.wikipedia.org/wiki/Horsepower#Engine_power_test_codes). * Note 2: You can link to information about how the given value has been determined using the [[valueReference]] property. * Note 3: You can use [[minValue]] and [[maxValue]] to indicate ranges.",
    )
    engineDisplacement: Optional[
        Union[List[Union["QuantitativeValue", str]], "QuantitativeValue", str]
    ] = Field(
        default=None,
        description="The volume swept by all of the pistons inside the cylinders of an internal combustion engine in a single movement. Typical unit code(s): CMQ for cubic centimeter, LTR for liters, INQ for cubic inches * Note 1: You can link to information about how the given value has been determined using the [[valueReference]] property. * Note 2: You can use [[minValue]] and [[maxValue]] to indicate ranges.",
    )
    engineType: Optional[
        Union[
            List[Union[AnyUrl, "URL", str, "Text", "QualitativeValue"]],
            AnyUrl,
            "URL",
            str,
            "Text",
            "QualitativeValue",
        ]
    ] = Field(
        default=None,
        description="The type of engine or engines powering the vehicle.",
    )
    torque: Optional[
        Union[List[Union["QuantitativeValue", str]], "QuantitativeValue", str]
    ] = Field(
        default=None,
        description="The torque (turning force) of the vehicle's engine. Typical unit code(s): NU for newton metre (N m), F17 for pound-force per foot, or F48 for pound-force per inch * Note 1: You can link to information about how the given value has been determined (e.g. reference RPM) using the [[valueReference]] property. * Note 2: You can use [[minValue]] and [[maxValue]] to indicate ranges.",
    )
    fuelType: Optional[
        Union[
            List[Union[AnyUrl, "URL", str, "Text", "QualitativeValue"]],
            AnyUrl,
            "URL",
            str,
            "Text",
            "QualitativeValue",
        ]
    ] = Field(
        default=None,
        description="The type of fuel suitable for the engine or engines of the vehicle. If the vehicle has only one engine, this property can be attached directly to the vehicle.",
    )


if TYPE_CHECKING:
    from pydantic2_schemaorg.QuantitativeValue import QuantitativeValue
    from pydantic2_schemaorg.URL import URL
    from pydantic2_schemaorg.Text import Text
    from pydantic2_schemaorg.QualitativeValue import QualitativeValue



from __future__ import annotations


from pydantic.v1 import Field
from pydantic2_schemaorg.Store import Store


class LiquorStore(Store):
    """A shop that sells alcoholic drinks such as wine, beer, whisky and other spirits.

    See: https://schema.org/LiquorStore
    Model depth: 5
    """

    type_: str = Field(default="LiquorStore", alias="@type", const=True)



from __future__ import annotations


from pydantic.v1 import Field
from pydantic2_schemaorg.Action import Action


class AchieveAction(Action):
    """The act of accomplishing something via previous efforts. It is an instantaneous action rather than an ongoing
     process.

    See: https://schema.org/AchieveAction
    Model depth: 3
    """

    type_: str = Field(default="AchieveAction", alias="@type", const=True)



from __future__ import annotations


from pydantic.v1 import Field
from pydantic2_schemaorg.Quantity import Quantity


class Mass(Quantity):
    """Properties that take Mass as values are of the form '&lt;Number&gt; &lt;Mass unit of measure&gt;'. E.g.,
     '7 kg'.

    See: https://schema.org/Mass
    Model depth: 4
    """

    type_: str = Field(default="Mass", alias="@type", const=True)



from __future__ import annotations
from typing import TYPE_CHECKING

from typing import List, Optional, Union
from pydantic.v1 import AnyUrl, StrictBool, StrictInt, StrictFloat
from datetime import date, datetime, time


from pydantic.v1 import Field
from pydantic2_schemaorg.Intangible import Intangible


class Offer(Intangible):
    """An offer to transfer some rights to an item or to provide a service — for example, an offer to sell tickets to an
     event, to rent the DVD of a movie, to stream a TV show over the internet, to repair a motorcycle, or to loan a book.
     Note: As the [[businessFunction]] property, which identifies the form of offer (e.g. sell, lease, repair,
     dispose), defaults to http://purl.org/goodrelations/v1#Sell; an Offer without a defined businessFunction
     value can be assumed to be an offer to sell. For [GTIN](http://www.gs1.org/barcodes/technical/idkeys/gtin)-related
     fields, see [Check Digit calculator](http://www.gs1.org/barcodes/support/check_digit_calculator)
     and [validation guide](http://www.gs1us.org/resources/standards/gtin-validation-guide) from [GS1](http://www.gs1.org/).

    See: https://schema.org/Offer
    Model depth: 3
    """

    type_: str = Field(default="Offer", alias="@type", const=True)
    warranty: Optional[
        Union[List[Union["WarrantyPromise", str]], "WarrantyPromise", str]
    ] = Field(
        default=None,
        description="The warranty promise(s) included in the offer.",
    )
    isFamilyFriendly: Optional[
        Union[List[Union[StrictBool, "Boolean", str]], StrictBool, "Boolean", str]
    ] = Field(
        default=None,
        description="Indicates whether this content is family friendly.",
    )
    eligibleRegion: Optional[
        Union[
            List[Union[str, "Text", "Place", "GeoShape"]],
            str,
            "Text",
            "Place",
            "GeoShape",
        ]
    ] = Field(
        default=None,
        description="The ISO 3166-1 (ISO 3166-1 alpha-2) or ISO 3166-2 code, the place, or the GeoShape for the geo-political region(s) for which the offer or delivery charge specification is valid. See also [[ineligibleRegion]].",
    )
    priceCurrency: Optional[Union[List[Union[str, "Text"]], str, "Text"]] = Field(
        default=None,
        description='The currency of the price, or a price component when attached to [[PriceSpecification]] and its subtypes. Use standard formats: [ISO 4217 currency format](http://en.wikipedia.org/wiki/ISO_4217), e.g. "USD"; [Ticker symbol](https://en.wikipedia.org/wiki/List_of_cryptocurrencies) for cryptocurrencies, e.g. "BTC"; well known names for [Local Exchange Trading Systems](https://en.wikipedia.org/wiki/Local_exchange_trading_system) (LETS) and other currency types, e.g. "Ithaca HOUR".',
    )
    gtin8: Optional[Union[List[Union[str, "Text"]], str, "Text"]] = Field(
        default=None,
        description="The GTIN-8 code of the product, or the product to which the offer refers. This code is also known as EAN/UCC-8 or 8-digit EAN. See [GS1 GTIN Summary](http://www.gs1.org/barcodes/technical/idkeys/gtin) for more details.",
    )
    category: Optional[
        Union[
            List[
                Union[
                    AnyUrl,
                    "URL",
                    str,
                    "Text",
                    "PhysicalActivityCategory",
                    "CategoryCode",
                    "Thing",
                ]
            ],
            AnyUrl,
            "URL",
            str,
            "Text",
            "PhysicalActivityCategory",
            "CategoryCode",
            "Thing",
        ]
    ] = Field(
        default=None,
        description="A category for the item. Greater signs or slashes can be used to informally indicate a category hierarchy.",
    )
    gtin: Optional[
        Union[List[Union[AnyUrl, "URL", str, "Text"]], AnyUrl, "URL", str, "Text"]
    ] = Field(
        default=None,
        description='A Global Trade Item Number ([GTIN](https://www.gs1.org/standards/id-keys/gtin)). GTINs identify trade items, including products and services, using numeric identification codes. A correct [[gtin]] value should be a valid GTIN, which means that it should be an all-numeric string of either 8, 12, 13 or 14 digits, or a "GS1 Digital Link" URL based on such a string. The numeric component should also have a [valid GS1 check digit](https://www.gs1.org/services/check-digit-calculator) and meet the other rules for valid GTINs. See also [GS1\'s GTIN Summary](http://www.gs1.org/barcodes/technical/idkeys/gtin) and [Wikipedia](https://en.wikipedia.org/wiki/Global_Trade_Item_Number) for more details. Left-padding of the gtin values is not required or encouraged. The [[gtin]] property generalizes the earlier [[gtin8]], [[gtin12]], [[gtin13]], and [[gtin14]] properties. The GS1 [digital link specifications](https://www.gs1.org/standards/Digital-Link/) expresses GTINs as URLs (URIs, IRIs, etc.). Digital Links should be populated into the [[hasGS1DigitalLink]] attribute. Note also that this is a definition for how to include GTINs in Schema.org data, and not a definition of GTINs in general - see the GS1 documentation for authoritative details.',
    )
    validFrom: Optional[
        Union[
            List[Union[datetime, "DateTime", date, "Date", str]],
            datetime,
            "DateTime",
            date,
            "Date",
            str,
        ]
    ] = Field(
        default=None,
        description="The date when the item becomes valid.",
    )
    inventoryLevel: Optional[
        Union[List[Union["QuantitativeValue", str]], "QuantitativeValue", str]
    ] = Field(
        default=None,
        description="The current approximate inventory level for the item or items.",
    )
    itemCondition: Optional[
        Union[List[Union["OfferItemCondition", str]], "OfferItemCondition", str]
    ] = Field(
        default=None,
        description="A predefined value from OfferItemCondition specifying the condition of the product or service, or the products or services included in the offer. Also used for product return policies to specify the condition of products accepted for returns.",
    )
    sku: Optional[Union[List[Union[str, "Text"]], str, "Text"]] = Field(
        default=None,
        description="The Stock Keeping Unit (SKU), i.e. a merchant-specific identifier for a product or service, or the product to which the offer refers.",
    )
    eligibleTransactionVolume: Optional[
        Union[List[Union["PriceSpecification", str]], "PriceSpecification", str]
    ] = Field(
        default=None,
        description="The transaction volume, in a monetary unit, for which the offer or price specification is valid, e.g. for indicating a minimal purchasing volume, to express free shipping above a certain order volume, or to limit the acceptance of credit cards to purchases to a certain minimal amount.",
    )
    includesObject: Optional[
        Union[List[Union["TypeAndQuantityNode", str]], "TypeAndQuantityNode", str]
    ] = Field(
        default=None,
        description="This links to a node or nodes indicating the exact quantity of the products included in an [[Offer]] or [[ProductCollection]].",
    )
    hasGS1DigitalLink: Optional[
        Union[List[Union[AnyUrl, "URL", str]], AnyUrl, "URL", str]
    ] = Field(
        default=None,
        description='The <a href="https://www.gs1.org/standards/gs1-digital-link">GS1 digital link</a> associated with the object. This URL should conform to the particular requirements of digital links. The link should only contain the Application Identifiers (AIs) that are relevant for the entity being annotated, for instance a [[Product]] or an [[Organization]], and for the correct granularity. In particular, for products:<ul><li>A Digital Link that contains a serial number (AI <code>21</code>) should only be present on instances of [[IndividualProduct]]</li><li>A Digital Link that contains a lot number (AI <code>10</code>) should be annotated as [[SomeProduct]] if only products from that lot are sold, or [[IndividualProduct]] if there is only a specific product.</li><li>A Digital Link that contains a global model number (AI <code>8013</code>) should be attached to a [[Product]] or a [[ProductModel]].</li></ul> Other item types should be adapted similarly.',
    )
    hasAdultConsideration: Optional[
        Union[
            List[Union["AdultOrientedEnumeration", str]],
            "AdultOrientedEnumeration",
            str,
        ]
    ] = Field(
        default=None,
        description="Used to tag an item to be intended or suitable for consumption or use by adults only.",
    )
    addOn: Optional[Union[List[Union["Offer", str]], "Offer", str]] = Field(
        default=None,
        description="An additional offer that can only be obtained in combination with the first base offer (e.g. supplements and extensions that are available for a surcharge).",
    )
    hasMerchantReturnPolicy: Optional[
        Union[List[Union["MerchantReturnPolicy", str]], "MerchantReturnPolicy", str]
    ] = Field(
        default=None,
        description="Specifies a MerchantReturnPolicy that may be applicable.",
    )
    aggregateRating: Optional[
        Union[List[Union["AggregateRating", str]], "AggregateRating", str]
    ] = Field(
        default=None,
        description="The overall rating, based on a collection of reviews or ratings, of the item.",
    )
    priceValidUntil: Optional[
        Union[List[Union[date, "Date", str]], date, "Date", str]
    ] = Field(
        default=None,
        description="The date after which the price is no longer available.",
    )
    availability: Optional[
        Union[List[Union["ItemAvailability", str]], "ItemAvailability", str]
    ] = Field(
        default=None,
        description="The availability of this item&#x2014;for example In stock, Out of stock, Pre-order, etc.",
    )
    hasMeasurement: Optional[
        Union[List[Union["QuantitativeValue", str]], "QuantitativeValue", str]
    ] = Field(
        default=None,
        description="A measurement of an item, For example, the inseam of pants, the wheel size of a bicycle, the gauge of a screw, or the carbon footprint measured for certification by an authority. Usually an exact measurement, but can also be a range of measurements for adjustable products, for example belts and ski bindings.",
    )
    seller: Optional[
        Union[List[Union["Person", "Organization", str]], "Person", "Organization", str]
    ] = Field(
        default=None,
        description="An entity which offers (sells / leases / lends / loans) the services / goods. A seller may also be a provider.",
    )
    businessFunction: Optional[
        Union[List[Union["BusinessFunction", str]], "BusinessFunction", str]
    ] = Field(
        default=None,
        description="The business function (e.g. sell, lease, repair, dispose) of the offer or component of a bundle (TypeAndQuantityNode). The default is http://purl.org/goodrelations/v1#Sell.",
    )
    eligibleDuration: Optional[
        Union[List[Union["QuantitativeValue", str]], "QuantitativeValue", str]
    ] = Field(
        default=None,
        description="The duration for which the given offer is valid.",
    )
    mobileUrl: Optional[Union[List[Union[str, "Text"]], str, "Text"]] = Field(
        default=None,
        description="The [[mobileUrl]] property is provided for specific situations in which data consumers need to determine whether one of several provided URLs is a dedicated 'mobile site'. To discourage over-use, and reflecting intial usecases, the property is expected only on [[Product]] and [[Offer]], rather than [[Thing]]. The general trend in web technology is towards [responsive design](https://en.wikipedia.org/wiki/Responsive_web_design) in which content can be flexibly adapted to a wide range of browsing environments. Pages and sites referenced with the long-established [[url]] property should ideally also be usable on a wide variety of devices, including mobile phones. In most cases, it would be pointless and counter productive to attempt to update all [[url]] markup to use [[mobileUrl]] for more mobile-oriented pages. The property is intended for the case when items (primarily [[Product]] and [[Offer]]) have extra URLs hosted on an additional \"mobile site\" alongside the main one. It should not be taken as an endorsement of this publication style.",
    )
    offeredBy: Optional[
        Union[List[Union["Person", "Organization", str]], "Person", "Organization", str]
    ] = Field(
        default=None,
        description="A pointer to the organization or person making the offer.",
    )
    eligibleCustomerType: Optional[
        Union[List[Union["BusinessEntityType", str]], "BusinessEntityType", str]
    ] = Field(
        default=None,
        description="The type(s) of customers for which the given offer is valid.",
    )
    eligibleQuantity: Optional[
        Union[List[Union["QuantitativeValue", str]], "QuantitativeValue", str]
    ] = Field(
        default=None,
        description="The interval and unit of measurement of ordering quantities for which the offer or price specification is valid. This allows e.g. specifying that a certain freight charge is valid only for a certain quantity.",
    )
    acceptedPaymentMethod: Optional[
        Union[
            List[Union["PaymentMethod", "LoanOrCredit", str]],
            "PaymentMethod",
            "LoanOrCredit",
            str,
        ]
    ] = Field(
        default=None,
        description="The payment method(s) that are accepted in general by an organization, or for some specific demand or offer.",
    )
    gtin14: Optional[Union[List[Union[str, "Text"]], str, "Text"]] = Field(
        default=None,
        description="The GTIN-14 code of the product, or the product to which the offer refers. See [GS1 GTIN Summary](http://www.gs1.org/barcodes/technical/idkeys/gtin) for more details.",
    )
    deliveryLeadTime: Optional[
        Union[List[Union["QuantitativeValue", str]], "QuantitativeValue", str]
    ] = Field(
        default=None,
        description="The typical delay between the receipt of the order and the goods either leaving the warehouse or being prepared for pickup, in case the delivery method is on site pickup.",
    )
    serialNumber: Optional[Union[List[Union[str, "Text"]], str, "Text"]] = Field(
        default=None,
        description="The serial number or any alphanumeric identifier of a particular product. When attached to an offer, it is a shortcut for the serial number of the product included in the offer.",
    )
    validForMemberTier: Optional[
        Union[List[Union["MemberProgramTier", str]], "MemberProgramTier", str]
    ] = Field(
        default=None,
        description="The membership program tier an Offer (or a PriceSpecification, OfferShippingDetails, or MerchantReturnPolicy under an Offer) is valid for.",
    )
    gtin13: Optional[Union[List[Union[str, "Text"]], str, "Text"]] = Field(
        default=None,
        description="The GTIN-13 code of the product, or the product to which the offer refers. This is equivalent to 13-digit ISBN codes and EAN UCC-13. Former 12-digit UPC codes can be converted into a GTIN-13 code by simply adding a preceding zero. See [GS1 GTIN Summary](http://www.gs1.org/barcodes/technical/idkeys/gtin) for more details.",
    )
    review: Optional[Union[List[Union["Review", str]], "Review", str]] = Field(
        default=None,
        description="A review of the item.",
    )
    gtin12: Optional[Union[List[Union[str, "Text"]], str, "Text"]] = Field(
        default=None,
        description="The GTIN-12 code of the product, or the product to which the offer refers. The GTIN-12 is the 12-digit GS1 Identification Key composed of a U.P.C. Company Prefix, Item Reference, and Check Digit used to identify trade items. See [GS1 GTIN Summary](http://www.gs1.org/barcodes/technical/idkeys/gtin) for more details.",
    )
    areaServed: Optional[
        Union[
            List[Union[str, "Text", "Place", "GeoShape", "AdministrativeArea"]],
            str,
            "Text",
            "Place",
            "GeoShape",
            "AdministrativeArea",
        ]
    ] = Field(
        default=None,
        description="The geographic area where a service or offered item is provided.",
    )
    asin: Optional[
        Union[List[Union[AnyUrl, "URL", str, "Text"]], AnyUrl, "URL", str, "Text"]
    ] = Field(
        default=None,
        description="An Amazon Standard Identification Number (ASIN) is a 10-character alphanumeric unique identifier assigned by Amazon.com and its partners for product identification within the Amazon organization (summary from [Wikipedia](https://en.wikipedia.org/wiki/Amazon_Standard_Identification_Number)'s article). Note also that this is a definition for how to include ASINs in Schema.org data, and not a definition of ASINs in general - see documentation from Amazon for authoritative details. ASINs are most commonly encoded as text strings, but the [asin] property supports URL/URI as potential values too.",
    )
    price: Optional[
        Union[
            List[Union[StrictInt, StrictFloat, "Number", str, "Text"]],
            StrictInt,
            StrictFloat,
            "Number",
            str,
            "Text",
        ]
    ] = Field(
        default=None,
        description="The offer price of a product, or of a price component when attached to PriceSpecification and its subtypes. Usage guidelines: * Use the [[priceCurrency]] property (with standard formats: [ISO 4217 currency format](http://en.wikipedia.org/wiki/ISO_4217), e.g. \"USD\"; [Ticker symbol](https://en.wikipedia.org/wiki/List_of_cryptocurrencies) for cryptocurrencies, e.g. \"BTC\"; well known names for [Local Exchange Trading Systems](https://en.wikipedia.org/wiki/Local_exchange_trading_system) (LETS) and other currency types, e.g. \"Ithaca HOUR\") instead of including [ambiguous symbols](http://en.wikipedia.org/wiki/Dollar_sign#Currencies_that_use_the_dollar_or_peso_sign) such as '$' in the value. * Use '.' (Unicode 'FULL STOP' (U+002E)) rather than ',' to indicate a decimal point. Avoid using these symbols as a readability separator. * Note that both [RDFa](http://www.w3.org/TR/xhtml-rdfa-primer/#using-the-content-attribute) and Microdata syntax allow the use of a \"content=\" attribute for publishing simple machine-readable values alongside more human-friendly formatting. * Use values from 0123456789 (Unicode 'DIGIT ZERO' (U+0030) to 'DIGIT NINE' (U+0039)) rather than superficially similar Unicode symbols.",
    )
    validThrough: Optional[
        Union[
            List[Union[datetime, "DateTime", date, "Date", str]],
            datetime,
            "DateTime",
            date,
            "Date",
            str,
        ]
    ] = Field(
        default=None,
        description="The date after when the item is not valid. For example the end of an offer, salary period, or a period of opening hours.",
    )
    availabilityEnds: Optional[
        Union[
            List[Union[datetime, "DateTime", time, "Time", date, "Date", str]],
            datetime,
            "DateTime",
            time,
            "Time",
            date,
            "Date",
            str,
        ]
    ] = Field(
        default=None,
        description="The end of the availability of the product or service included in the offer.",
    )
    additionalProperty: Optional[
        Union[List[Union["PropertyValue", str]], "PropertyValue", str]
    ] = Field(
        default=None,
        description="A property-value pair representing an additional characteristic of the entity, e.g. a product feature or another characteristic for which there is no matching property in schema.org. Note: Publishers should be aware that applications designed to use specific schema.org properties (e.g. https://schema.org/width, https://schema.org/color, https://schema.org/gtin13, ...) will typically expect such data to be provided using those properties, rather than using the generic property/value mechanism.",
    )
    availableDeliveryMethod: Optional[
        Union[List[Union["DeliveryMethod", str]], "DeliveryMethod", str]
    ] = Field(
        default=None,
        description="The delivery method(s) available for this offer.",
    )
    priceSpecification: Optional[
        Union[List[Union["PriceSpecification", str]], "PriceSpecification", str]
    ] = Field(
        default=None,
        description="One or more detailed price specifications, indicating the unit price and delivery or payment charges.",
    )
    checkoutPageURLTemplate: Optional[Union[List[Union[str, "Text"]], str, "Text"]] = (
        Field(
            default=None,
            description="A URL template (RFC 6570) for a checkout page for an offer. This approach allows merchants to specify a URL for online checkout of the offered product, by interpolating parameters such as the logged in user ID, product ID, quantity, discount code etc. Parameter naming and standardization are not specified here.",
        )
    )
    leaseLength: Optional[
        Union[
            List[Union["Duration", "QuantitativeValue", str]],
            "Duration",
            "QuantitativeValue",
            str,
        ]
    ] = Field(
        default=None,
        description="Length of the lease for some [[Accommodation]], either particular to some [[Offer]] or in some cases intrinsic to the property.",
    )
    availabilityStarts: Optional[
        Union[
            List[Union[datetime, "DateTime", time, "Time", date, "Date", str]],
            datetime,
            "DateTime",
            time,
            "Time",
            date,
            "Date",
            str,
        ]
    ] = Field(
        default=None,
        description="The beginning of the availability of the product or service included in the offer.",
    )
    shippingDetails: Optional[
        Union[List[Union["OfferShippingDetails", str]], "OfferShippingDetails", str]
    ] = Field(
        default=None,
        description="Indicates information about the shipping policies and options associated with an [[Offer]].",
    )
    itemOffered: Optional[
        Union[
            List[
                Union[
                    "Service",
                    "Event",
                    "CreativeWork",
                    "Trip",
                    "MenuItem",
                    "Product",
                    "AggregateOffer",
                    str,
                ]
            ],
            "Service",
            "Event",
            "CreativeWork",
            "Trip",
            "MenuItem",
            "Product",
            "AggregateOffer",
            str,
        ]
    ] = Field(
        default=None,
        description="An item being offered (or demanded). The transactional nature of the offer or demand is documented using [[businessFunction]], e.g. sell, lease etc. While several common expected types are listed explicitly in this definition, others can be used. Using a second type, such as Product or a subtype of Product, can clarify the nature of the offer.",
    )
    advanceBookingRequirement: Optional[
        Union[List[Union["QuantitativeValue", str]], "QuantitativeValue", str]
    ] = Field(
        default=None,
        description="The amount of time that is required between accepting the offer and the actual usage of the resource or service.",
    )
    mpn: Optional[Union[List[Union[str, "Text"]], str, "Text"]] = Field(
        default=None,
        description="The Manufacturer Part Number (MPN) of the product, or the product to which the offer refers.",
    )
    ineligibleRegion: Optional[
        Union[
            List[Union[str, "Text", "Place", "GeoShape"]],
            str,
            "Text",
            "Place",
            "GeoShape",
        ]
    ] = Field(
        default=None,
        description="The ISO 3166-1 (ISO 3166-1 alpha-2) or ISO 3166-2 code, the place, or the GeoShape for the geo-political region(s) for which the offer or delivery charge specification is not valid, e.g. a region where the transaction is not allowed. See also [[eligibleRegion]].",
    )
    availableAtOrFrom: Optional[Union[List[Union["Place", str]], "Place", str]] = Field(
        default=None,
        description="The place(s) from which the offer can be obtained (e.g. store locations).",
    )
    reviews: Optional[Union[List[Union["Review", str]], "Review", str]] = Field(
        default=None,
        description="Review of the item.",
    )


if TYPE_CHECKING:
    from pydantic2_schemaorg.WarrantyPromise import WarrantyPromise
    from pydantic2_schemaorg.Boolean import Boolean
    from pydantic2_schemaorg.Text import Text
    from pydantic2_schemaorg.Place import Place
    from pydantic2_schemaorg.GeoShape import GeoShape
    from pydantic2_schemaorg.URL import URL
    from pydantic2_schemaorg.PhysicalActivityCategory import PhysicalActivityCategory
    from pydantic2_schemaorg.CategoryCode import CategoryCode
    from pydantic2_schemaorg.Thing import Thing
    from pydantic2_schemaorg.DateTime import DateTime
    from pydantic2_schemaorg.Date import Date
    from pydantic2_schemaorg.QuantitativeValue import QuantitativeValue
    from pydantic2_schemaorg.OfferItemCondition import OfferItemCondition
    from pydantic2_schemaorg.PriceSpecification import PriceSpecification
    from pydantic2_schemaorg.TypeAndQuantityNode import TypeAndQuantityNode
    from pydantic2_schemaorg.AdultOrientedEnumeration import AdultOrientedEnumeration
    from pydantic2_schemaorg.MerchantReturnPolicy import MerchantReturnPolicy
    from pydantic2_schemaorg.AggregateRating import AggregateRating
    from pydantic2_schemaorg.ItemAvailability import ItemAvailability
    from pydantic2_schemaorg.Person import Person
    from pydantic2_schemaorg.Organization import Organization
    from pydantic2_schemaorg.BusinessFunction import BusinessFunction
    from pydantic2_schemaorg.BusinessEntityType import BusinessEntityType
    from pydantic2_schemaorg.PaymentMethod import PaymentMethod
    from pydantic2_schemaorg.LoanOrCredit import LoanOrCredit
    from pydantic2_schemaorg.MemberProgramTier import MemberProgramTier
    from pydantic2_schemaorg.Review import Review
    from pydantic2_schemaorg.AdministrativeArea import AdministrativeArea
    from pydantic2_schemaorg.Number import Number
    from pydantic2_schemaorg.Time import Time
    from pydantic2_schemaorg.PropertyValue import PropertyValue
    from pydantic2_schemaorg.DeliveryMethod import DeliveryMethod
    from pydantic2_schemaorg.Duration import Duration
    from pydantic2_schemaorg.OfferShippingDetails import OfferShippingDetails
    from pydantic2_schemaorg.Service import Service
    from pydantic2_schemaorg.Event import Event
    from pydantic2_schemaorg.CreativeWork import CreativeWork
    from pydantic2_schemaorg.Trip import Trip
    from pydantic2_schemaorg.MenuItem import MenuItem
    from pydantic2_schemaorg.Product import Product
    from pydantic2_schemaorg.AggregateOffer import AggregateOffer



from __future__ import annotations
from typing import TYPE_CHECKING

from typing import List, Optional, Union
from pydantic.v1 import AnyUrl


from pydantic.v1 import Field
from pydantic2_schemaorg.CreativeWork import CreativeWork


class Game(CreativeWork):
    """The Game type represents things which are games. These are typically rule-governed recreational activities,
     e.g. role-playing games in which players assume the role of characters in a fictional setting.

    See: https://schema.org/Game
    Model depth: 3
    """

    type_: str = Field(default="Game", alias="@type", const=True)
    gameItem: Optional[Union[List[Union["Thing", str]], "Thing", str]] = Field(
        default=None,
        description="An item is an object within the game world that can be collected by a player or, occasionally, a non-player character.",
    )
    quest: Optional[Union[List[Union["Thing", str]], "Thing", str]] = Field(
        default=None,
        description="The task that a player-controlled character, or group of characters may complete in order to gain a reward.",
    )
    numberOfPlayers: Optional[
        Union[List[Union["QuantitativeValue", str]], "QuantitativeValue", str]
    ] = Field(
        default=None,
        description="Indicate how many people can play this game (minimum, maximum, or range).",
    )
    characterAttribute: Optional[Union[List[Union["Thing", str]], "Thing", str]] = (
        Field(
            default=None,
            description="A piece of data that represents a particular aspect of a fictional character (skill, power, character points, advantage, disadvantage).",
        )
    )
    gameLocation: Optional[
        Union[
            List[Union[AnyUrl, "URL", "Place", "PostalAddress", str]],
            AnyUrl,
            "URL",
            "Place",
            "PostalAddress",
            str,
        ]
    ] = Field(
        default=None,
        description="Real or fictional location of the game (or part of game).",
    )


if TYPE_CHECKING:
    from pydantic2_schemaorg.Thing import Thing
    from pydantic2_schemaorg.QuantitativeValue import QuantitativeValue
    from pydantic2_schemaorg.URL import URL
    from pydantic2_schemaorg.Place import Place
    from pydantic2_schemaorg.PostalAddress import PostalAddress



from __future__ import annotations


from pydantic.v1 import Field
from pydantic2_schemaorg.Service import Service


class TaxiService(Service):
    """A service for a vehicle for hire with a driver for local travel. Fares are usually calculated based on distance
     traveled.

    See: https://schema.org/TaxiService
    Model depth: 4
    """

    type_: str = Field(default="TaxiService", alias="@type", const=True)



from __future__ import annotations
from typing import TYPE_CHECKING

from typing import List, Optional, Union


from pydantic.v1 import Field
from pydantic2_schemaorg.WebContent import WebContent


class HealthTopicContent(WebContent):
    """[[HealthTopicContent]] is [[WebContent]] that is about some aspect of a health topic, e.g. a condition,
     its symptoms or treatments. Such content may be comprised of several parts or sections and use different types
     of media. Multiple instances of [[WebContent]] (and hence [[HealthTopicContent]]) can be related using
     [[hasPart]] / [[isPartOf]] where there is some kind of content hierarchy, and their content described with
     [[about]] and [[mentions]] e.g. building upon the existing [[MedicalCondition]] vocabulary.

    See: https://schema.org/HealthTopicContent
    Model depth: 4
    """

    type_: str = Field(default="HealthTopicContent", alias="@type", const=True)
    hasHealthAspect: Optional[
        Union[
            List[Union["HealthAspectEnumeration", str]], "HealthAspectEnumeration", str
        ]
    ] = Field(
        default=None,
        description="Indicates the aspect or aspects specifically addressed in some [[HealthTopicContent]]. For example, that the content is an overview, or that it talks about treatment, self-care, treatments or their side-effects.",
    )


if TYPE_CHECKING:
    from pydantic2_schemaorg.HealthAspectEnumeration import HealthAspectEnumeration



from __future__ import annotations


from pydantic.v1 import Field
from pydantic2_schemaorg.MedicalObservationalStudyDesign import (
    MedicalObservationalStudyDesign,
)


class CohortStudy(MedicalObservationalStudyDesign):
    """Also known as a panel study. A cohort study is a form of longitudinal study used in medicine and social science.
     It is one type of study design and should be compared with a cross-sectional study. A cohort is a group of people
     who share a common characteristic or experience within a defined period (e.g., are born, leave school, lose
     their job, are exposed to a drug or a vaccine, etc.). The comparison group may be the general population from
     which the cohort is drawn, or it may be another cohort of persons thought to have had little or no exposure to
     the substance under investigation, but otherwise similar. Alternatively, subgroups within the cohort
     may be compared with each other.

    See: https://schema.org/CohortStudy
    Model depth: 6
    """

    type_: str = Field(default="CohortStudy", alias="@type", const=True)



from __future__ import annotations


from pydantic.v1 import Field
from pydantic2_schemaorg.Action import Action


class FindAction(Action):
    """The act of finding an object. Related actions: * [[SearchAction]]: FindAction is generally lead by a SearchAction,
     but not necessarily.

    See: https://schema.org/FindAction
    Model depth: 3
    """

    type_: str = Field(default="FindAction", alias="@type", const=True)



from __future__ import annotations
from typing import TYPE_CHECKING

from typing import List, Optional, Union


from pydantic.v1 import Field
from pydantic2_schemaorg.MedicalBusiness import MedicalBusiness
from pydantic2_schemaorg.MedicalOrganization import MedicalOrganization


class Physician(MedicalBusiness, MedicalOrganization):
    """An individual physician or a physician's office considered as a [[MedicalOrganization]].

    See: https://schema.org/Physician
    Model depth: 4
    """

    type_: str = Field(default="Physician", alias="@type", const=True)
    occupationalCategory: Optional[
        Union[List[Union[str, "Text", "CategoryCode"]], str, "Text", "CategoryCode"]
    ] = Field(
        default=None,
        description="A category describing the job, preferably using a term from a taxonomy such as [BLS O*NET-SOC](http://www.onetcenter.org/taxonomy.html), [ISCO-08](https://www.ilo.org/public/english/bureau/stat/isco/isco08/) or similar, with the property repeated for each applicable value. Ideally the taxonomy should be identified, and both the textual label and formal code for the category should be provided. Note: for historical reasons, any textual label and formal code provided as a literal may be assumed to be from O*NET-SOC.",
    )
    hospitalAffiliation: Optional[
        Union[List[Union["Hospital", str]], "Hospital", str]
    ] = Field(
        default=None,
        description="A hospital with which the physician or office is affiliated.",
    )
    availableService: Optional[
        Union[
            List[Union["MedicalTherapy", "MedicalProcedure", "MedicalTest", str]],
            "MedicalTherapy",
            "MedicalProcedure",
            "MedicalTest",
            str,
        ]
    ] = Field(
        default=None,
        description="A medical service available from this provider.",
    )
    usNPI: Optional[Union[List[Union[str, "Text"]], str, "Text"]] = Field(
        default=None,
        description='A <a href="https://en.wikipedia.org/wiki/National_Provider_Identifier">National Provider Identifier</a> (NPI) is a unique 10-digit identification number issued to health care providers in the United States by the Centers for Medicare and Medicaid Services.',
    )
    medicalSpecialty: Optional[
        Union[List[Union["MedicalSpecialty", str]], "MedicalSpecialty", str]
    ] = Field(
        default=None,
        description="A medical specialty of the provider.",
    )


if TYPE_CHECKING:
    from pydantic2_schemaorg.Text import Text
    from pydantic2_schemaorg.CategoryCode import CategoryCode
    from pydantic2_schemaorg.Hospital import Hospital
    from pydantic2_schemaorg.MedicalTherapy import MedicalTherapy
    from pydantic2_schemaorg.MedicalProcedure import MedicalProcedure
    from pydantic2_schemaorg.MedicalTest import MedicalTest
    from pydantic2_schemaorg.MedicalSpecialty import MedicalSpecialty



from __future__ import annotations


from pydantic.v1 import Field
from pydantic2_schemaorg.LodgingBusiness import LodgingBusiness


class VacationRental(LodgingBusiness):
    """A kind of lodging business that focuses on renting single properties for limited time.

    See: https://schema.org/VacationRental
    Model depth: 5
    """

    type_: str = Field(default="VacationRental", alias="@type", const=True)



from __future__ import annotations


from pydantic.v1 import Field
from pydantic2_schemaorg.MediaManipulationRatingEnumeration import (
    MediaManipulationRatingEnumeration,
)


class EditedOrCroppedContent(MediaManipulationRatingEnumeration):
    """Content coded 'edited or cropped content' in a [[MediaReview]], considered in the context of how it was published
     or shared. For a [[VideoObject]] to be 'edited or cropped content': The video has been edited or rearranged.
     This category applies to time edits, including editing multiple videos together to alter the story being
     told or editing out large portions from a video. For an [[ImageObject]] to be 'edited or cropped content':
     Presenting a part of an image from a larger whole to mislead the viewer. For an [[ImageObject]] with embedded
     text to be 'edited or cropped content': Presenting a part of an image from a larger whole to mislead the viewer.
     For an [[AudioObject]] to be 'edited or cropped content': The audio has been edited or rearranged. This category
     applies to time edits, including editing multiple audio clips together to alter the story being told or editing
     out large portions from the recording.

    See: https://schema.org/EditedOrCroppedContent
    Model depth: 5
    """

    type_: str = Field(default="EditedOrCroppedContent", alias="@type", const=True)



from __future__ import annotations


from pydantic.v1 import Field
from pydantic2_schemaorg.PriceComponentTypeEnumeration import (
    PriceComponentTypeEnumeration,
)


class ActivationFee(PriceComponentTypeEnumeration):
    """Represents the activation fee part of the total price for an offered product, for example a cellphone contract.

    See: https://schema.org/ActivationFee
    Model depth: 5
    """

    type_: str = Field(default="ActivationFee", alias="@type", const=True)



from __future__ import annotations


from pydantic.v1 import Field
from pydantic2_schemaorg.PhysicalExam import PhysicalExam


class Nose(PhysicalExam):
    """Nose function assessment with clinical examination.

    See: https://schema.org/Nose
    Model depth: 5
    """

    type_: str = Field(default="Nose", alias="@type", const=True)



from __future__ import annotations
from typing import TYPE_CHECKING

from pydantic.v1 import StrictInt, StrictFloat
from typing import List, Optional, Union


from pydantic.v1 import Field
from pydantic2_schemaorg.Intangible import Intangible


class OccupationalExperienceRequirements(Intangible):
    """Indicates employment-related experience requirements, e.g. [[monthsOfExperience]].

    See: https://schema.org/OccupationalExperienceRequirements
    Model depth: 3
    """

    type_: str = Field(
        default="OccupationalExperienceRequirements", alias="@type", const=True
    )
    monthsOfExperience: Optional[
        Union[
            List[Union[StrictInt, StrictFloat, "Number", str]],
            StrictInt,
            StrictFloat,
            "Number",
            str,
        ]
    ] = Field(
        default=None,
        description="Indicates the minimal number of months of experience required for a position.",
    )


if TYPE_CHECKING:
    from pydantic2_schemaorg.Number import Number



from __future__ import annotations


from pydantic.v1 import Field
from pydantic2_schemaorg.ControlAction import ControlAction


class ActivateAction(ControlAction):
    """The act of starting or activating a device or application (e.g. starting a timer or turning on a flashlight).

    See: https://schema.org/ActivateAction
    Model depth: 4
    """

    type_: str = Field(default="ActivateAction", alias="@type", const=True)



from __future__ import annotations


from pydantic.v1 import Field
from pydantic2_schemaorg.HealthAspectEnumeration import HealthAspectEnumeration


class RisksOrComplicationsHealthAspect(HealthAspectEnumeration):
    """Information about the risk factors and possible complications that may follow a topic.

    See: https://schema.org/RisksOrComplicationsHealthAspect
    Model depth: 5
    """

    type_: str = Field(
        default="RisksOrComplicationsHealthAspect", alias="@type", const=True
    )



from __future__ import annotations


from pydantic.v1 import Field
from pydantic2_schemaorg.MedicalSpecialty import MedicalSpecialty
from pydantic2_schemaorg.MedicalBusiness import MedicalBusiness


class Gynecologic(MedicalSpecialty, MedicalBusiness):
    """A specific branch of medical science that pertains to the health care of women, particularly in the diagnosis
     and treatment of disorders affecting the female reproductive system.

    See: https://schema.org/Gynecologic
    Model depth: 5
    """

    type_: str = Field(default="Gynecologic", alias="@type", const=True)



from __future__ import annotations


from pydantic.v1 import Field
from pydantic2_schemaorg.FoodEstablishment import FoodEstablishment


class Winery(FoodEstablishment):
    """A winery.

    See: https://schema.org/Winery
    Model depth: 5
    """

    type_: str = Field(default="Winery", alias="@type", const=True)



from __future__ import annotations


from pydantic.v1 import Field
from pydantic2_schemaorg.RsvpResponseType import RsvpResponseType


class RsvpResponseNo(RsvpResponseType):
    """The invitee will not attend.

    See: https://schema.org/RsvpResponseNo
    Model depth: 5
    """

    type_: str = Field(default="RsvpResponseNo", alias="@type", const=True)



from __future__ import annotations


from pydantic.v1 import Field
from pydantic2_schemaorg.USNonprofitType import USNonprofitType


class Nonprofit501c14(USNonprofitType):
    """Nonprofit501c14: Non-profit type referring to State-Chartered Credit Unions, Mutual Reserve Funds.

    See: https://schema.org/Nonprofit501c14
    Model depth: 6
    """

    type_: str = Field(default="Nonprofit501c14", alias="@type", const=True)



from __future__ import annotations
from typing import TYPE_CHECKING

from pydantic.v1 import AnyUrl
from typing import List, Optional, Union


from pydantic.v1 import Field
from pydantic2_schemaorg.Event import Event


class EducationEvent(Event):
    """Event type: Education event.

    See: https://schema.org/EducationEvent
    Model depth: 3
    """

    type_: str = Field(default="EducationEvent", alias="@type", const=True)
    educationalLevel: Optional[
        Union[
            List[Union[AnyUrl, "URL", str, "Text", "DefinedTerm"]],
            AnyUrl,
            "URL",
            str,
            "Text",
            "DefinedTerm",
        ]
    ] = Field(
        default=None,
        description="The level in terms of progression through an educational or training context. Examples of educational levels include 'beginner', 'intermediate' or 'advanced', and formal sets of level indicators.",
    )
    assesses: Optional[
        Union[List[Union[str, "Text", "DefinedTerm"]], str, "Text", "DefinedTerm"]
    ] = Field(
        default=None,
        description="The item being described is intended to assess the competency or learning outcome defined by the referenced term.",
    )
    teaches: Optional[
        Union[List[Union[str, "Text", "DefinedTerm"]], str, "Text", "DefinedTerm"]
    ] = Field(
        default=None,
        description="The item being described is intended to help a person learn the competency or learning outcome defined by the referenced term.",
    )


if TYPE_CHECKING:
    from pydantic2_schemaorg.URL import URL
    from pydantic2_schemaorg.Text import Text
    from pydantic2_schemaorg.DefinedTerm import DefinedTerm



from __future__ import annotations
from typing import TYPE_CHECKING

from typing import List, Optional, Union
from datetime import date
from pydantic.v1 import AnyUrl


from pydantic.v1 import Field
from pydantic2_schemaorg.CreativeWork import CreativeWork


class WebPage(CreativeWork):
    """A web page. Every web page is implicitly assumed to be declared to be of type WebPage, so the various properties
     about that webpage, such as <code>breadcrumb</code> may be used. We recommend explicit declaration if these
     properties are specified, but if they are found outside of an itemscope, they will be assumed to be about the
     page.

    See: https://schema.org/WebPage
    Model depth: 3
    """

    type_: str = Field(default="WebPage", alias="@type", const=True)
    breadcrumb: Optional[
        Union[List[Union[str, "Text", "BreadcrumbList"]], str, "Text", "BreadcrumbList"]
    ] = Field(
        default=None,
        description="A set of links that can help a user understand and navigate a website hierarchy.",
    )
    lastReviewed: Optional[Union[List[Union[date, "Date", str]], date, "Date", str]] = (
        Field(
            default=None,
            description="Date on which the content on this web page was last reviewed for accuracy and/or completeness.",
        )
    )
    relatedLink: Optional[
        Union[List[Union[AnyUrl, "URL", str]], AnyUrl, "URL", str]
    ] = Field(
        default=None,
        description="A link related to this web page, for example to other related web pages.",
    )
    speakable: Optional[
        Union[
            List[Union[AnyUrl, "URL", "SpeakableSpecification", str]],
            AnyUrl,
            "URL",
            "SpeakableSpecification",
            str,
        ]
    ] = Field(
        default=None,
        description="Indicates sections of a Web page that are particularly 'speakable' in the sense of being highlighted as being especially appropriate for text-to-speech conversion. Other sections of a page may also be usefully spoken in particular circumstances; the 'speakable' property serves to indicate the parts most likely to be generally useful for speech. The *speakable* property can be repeated an arbitrary number of times, with three kinds of possible 'content-locator' values: 1.) *id-value* URL references - uses *id-value* of an element in the page being annotated. The simplest use of *speakable* has (potentially relative) URL values, referencing identified sections of the document concerned. 2.) CSS Selectors - addresses content in the annotated page, e.g. via class attribute. Use the [[cssSelector]] property. 3.) XPaths - addresses content via XPaths (assuming an XML view of the content). Use the [[xpath]] property. For more sophisticated markup of speakable sections beyond simple ID references, either CSS selectors or XPath expressions to pick out document section(s) as speakable. For this we define a supporting type, [[SpeakableSpecification]] which is defined to be a possible value of the *speakable* property.",
    )
    significantLinks: Optional[
        Union[List[Union[AnyUrl, "URL", str]], AnyUrl, "URL", str]
    ] = Field(
        default=None,
        description="The most significant URLs on the page. Typically, these are the non-navigation links that are clicked on the most.",
    )
    specialty: Optional[Union[List[Union["Specialty", str]], "Specialty", str]] = Field(
        default=None,
        description="One of the domain specialities to which this web page's content applies.",
    )
    primaryImageOfPage: Optional[
        Union[List[Union["ImageObject", str]], "ImageObject", str]
    ] = Field(
        default=None,
        description="Indicates the main image on the page.",
    )
    significantLink: Optional[
        Union[List[Union[AnyUrl, "URL", str]], AnyUrl, "URL", str]
    ] = Field(
        default=None,
        description="One of the more significant URLs on the page. Typically, these are the non-navigation links that are clicked on the most.",
    )
    reviewedBy: Optional[
        Union[List[Union["Person", "Organization", str]], "Person", "Organization", str]
    ] = Field(
        default=None,
        description="People or organizations that have reviewed the content on this web page for accuracy and/or completeness.",
    )
    mainContentOfPage: Optional[
        Union[List[Union["WebPageElement", str]], "WebPageElement", str]
    ] = Field(
        default=None,
        description="Indicates if this web page element is the main subject of the page.",
    )


if TYPE_CHECKING:
    from pydantic2_schemaorg.Text import Text
    from pydantic2_schemaorg.BreadcrumbList import BreadcrumbList
    from pydantic2_schemaorg.Date import Date
    from pydantic2_schemaorg.URL import URL
    from pydantic2_schemaorg.SpeakableSpecification import SpeakableSpecification
    from pydantic2_schemaorg.Specialty import Specialty
    from pydantic2_schemaorg.ImageObject import ImageObject
    from pydantic2_schemaorg.Person import Person
    from pydantic2_schemaorg.Organization import Organization
    from pydantic2_schemaorg.WebPageElement import WebPageElement



from __future__ import annotations


from pydantic.v1 import Field
from pydantic2_schemaorg.WebPage import WebPage


class QAPage(WebPage):
    """A QAPage is a WebPage focussed on a specific Question and its Answer(s), e.g. in a question answering site or
     documenting Frequently Asked Questions (FAQs).

    See: https://schema.org/QAPage
    Model depth: 4
    """

    type_: str = Field(default="QAPage", alias="@type", const=True)



from __future__ import annotations


from pydantic.v1 import Field
from pydantic2_schemaorg.Enumeration import Enumeration


class DigitalDocumentPermissionType(Enumeration):
    """A type of permission which can be granted for accessing a digital document.

    See: https://schema.org/DigitalDocumentPermissionType
    Model depth: 4
    """

    type_: str = Field(
        default="DigitalDocumentPermissionType", alias="@type", const=True
    )



from __future__ import annotations
from typing import TYPE_CHECKING

from typing import List, Optional, Union


from pydantic.v1 import Field
from pydantic2_schemaorg.StructuredValue import StructuredValue


class NutritionInformation(StructuredValue):
    """Nutritional information about the recipe.

    See: https://schema.org/NutritionInformation
    Model depth: 4
    """

    type_: str = Field(default="NutritionInformation", alias="@type", const=True)
    transFatContent: Optional[Union[List[Union["Mass", str]], "Mass", str]] = Field(
        default=None,
        description="The number of grams of trans fat.",
    )
    sugarContent: Optional[Union[List[Union["Mass", str]], "Mass", str]] = Field(
        default=None,
        description="The number of grams of sugar.",
    )
    unsaturatedFatContent: Optional[Union[List[Union["Mass", str]], "Mass", str]] = (
        Field(
            default=None,
            description="The number of grams of unsaturated fat.",
        )
    )
    fatContent: Optional[Union[List[Union["Mass", str]], "Mass", str]] = Field(
        default=None,
        description="The number of grams of fat.",
    )
    fiberContent: Optional[Union[List[Union["Mass", str]], "Mass", str]] = Field(
        default=None,
        description="The number of grams of fiber.",
    )
    sodiumContent: Optional[Union[List[Union["Mass", str]], "Mass", str]] = Field(
        default=None,
        description="The number of milligrams of sodium.",
    )
    cholesterolContent: Optional[Union[List[Union["Mass", str]], "Mass", str]] = Field(
        default=None,
        description="The number of milligrams of cholesterol.",
    )
    carbohydrateContent: Optional[Union[List[Union["Mass", str]], "Mass", str]] = Field(
        default=None,
        description="The number of grams of carbohydrates.",
    )
    servingSize: Optional[Union[List[Union[str, "Text"]], str, "Text"]] = Field(
        default=None,
        description="The serving size, in terms of the number of volume or mass.",
    )
    calories: Optional[Union[List[Union["Energy", str]], "Energy", str]] = Field(
        default=None,
        description="The number of calories.",
    )
    saturatedFatContent: Optional[Union[List[Union["Mass", str]], "Mass", str]] = Field(
        default=None,
        description="The number of grams of saturated fat.",
    )
    proteinContent: Optional[Union[List[Union["Mass", str]], "Mass", str]] = Field(
        default=None,
        description="The number of grams of protein.",
    )


if TYPE_CHECKING:
    from pydantic2_schemaorg.Mass import Mass
    from pydantic2_schemaorg.Text import Text
    from pydantic2_schemaorg.Energy import Energy
